/* This file is automatically generated.  DO NOT EDIT! */

#include <config.h>
#include "data.h"

const struct idna_table idna_table[] = {
  {0x0000, 0x002C, DISALLOWED},
  {0x002D, 0x002D, PVALID},
  {0x002E, 0x002F, DISALLOWED},
  {0x0030, 0x0039, PVALID},
  {0x003A, 0x0060, DISALLOWED},
  {0x0061, 0x007A, PVALID},
  {0x007B, 0x00B6, DISALLOWED},
  {0x00B7, 0x00B7, CONTEXTO},
  {0x00B8, 0x00DE, DISALLOWED},
  {0x00DF, 0x00F6, PVALID},
  {0x00F7, 0x00F7, DISALLOWED},
  {0x00F8, 0x00FF, PVALID},
  {0x0100, 0x0100, DISALLOWED},
  {0x0101, 0x0101, PVALID},
  {0x0102, 0x0102, DISALLOWED},
  {0x0103, 0x0103, PVALID},
  {0x0104, 0x0104, DISALLOWED},
  {0x0105, 0x0105, PVALID},
  {0x0106, 0x0106, DISALLOWED},
  {0x0107, 0x0107, PVALID},
  {0x0108, 0x0108, DISALLOWED},
  {0x0109, 0x0109, PVALID},
  {0x010A, 0x010A, DISALLOWED},
  {0x010B, 0x010B, PVALID},
  {0x010C, 0x010C, DISALLOWED},
  {0x010D, 0x010D, PVALID},
  {0x010E, 0x010E, DISALLOWED},
  {0x010F, 0x010F, PVALID},
  {0x0110, 0x0110, DISALLOWED},
  {0x0111, 0x0111, PVALID},
  {0x0112, 0x0112, DISALLOWED},
  {0x0113, 0x0113, PVALID},
  {0x0114, 0x0114, DISALLOWED},
  {0x0115, 0x0115, PVALID},
  {0x0116, 0x0116, DISALLOWED},
  {0x0117, 0x0117, PVALID},
  {0x0118, 0x0118, DISALLOWED},
  {0x0119, 0x0119, PVALID},
  {0x011A, 0x011A, DISALLOWED},
  {0x011B, 0x011B, PVALID},
  {0x011C, 0x011C, DISALLOWED},
  {0x011D, 0x011D, PVALID},
  {0x011E, 0x011E, DISALLOWED},
  {0x011F, 0x011F, PVALID},
  {0x0120, 0x0120, DISALLOWED},
  {0x0121, 0x0121, PVALID},
  {0x0122, 0x0122, DISALLOWED},
  {0x0123, 0x0123, PVALID},
  {0x0124, 0x0124, DISALLOWED},
  {0x0125, 0x0125, PVALID},
  {0x0126, 0x0126, DISALLOWED},
  {0x0127, 0x0127, PVALID},
  {0x0128, 0x0128, DISALLOWED},
  {0x0129, 0x0129, PVALID},
  {0x012A, 0x012A, DISALLOWED},
  {0x012B, 0x012B, PVALID},
  {0x012C, 0x012C, DISALLOWED},
  {0x012D, 0x012D, PVALID},
  {0x012E, 0x012E, DISALLOWED},
  {0x012F, 0x012F, PVALID},
  {0x0130, 0x0130, DISALLOWED},
  {0x0131, 0x0131, PVALID},
  {0x0132, 0x0134, DISALLOWED},
  {0x0135, 0x0135, PVALID},
  {0x0136, 0x0136, DISALLOWED},
  {0x0137, 0x0138, PVALID},
  {0x0139, 0x0139, DISALLOWED},
  {0x013A, 0x013A, PVALID},
  {0x013B, 0x013B, DISALLOWED},
  {0x013C, 0x013C, PVALID},
  {0x013D, 0x013D, DISALLOWED},
  {0x013E, 0x013E, PVALID},
  {0x013F, 0x0141, DISALLOWED},
  {0x0142, 0x0142, PVALID},
  {0x0143, 0x0143, DISALLOWED},
  {0x0144, 0x0144, PVALID},
  {0x0145, 0x0145, DISALLOWED},
  {0x0146, 0x0146, PVALID},
  {0x0147, 0x0147, DISALLOWED},
  {0x0148, 0x0148, PVALID},
  {0x0149, 0x014A, DISALLOWED},
  {0x014B, 0x014B, PVALID},
  {0x014C, 0x014C, DISALLOWED},
  {0x014D, 0x014D, PVALID},
  {0x014E, 0x014E, DISALLOWED},
  {0x014F, 0x014F, PVALID},
  {0x0150, 0x0150, DISALLOWED},
  {0x0151, 0x0151, PVALID},
  {0x0152, 0x0152, DISALLOWED},
  {0x0153, 0x0153, PVALID},
  {0x0154, 0x0154, DISALLOWED},
  {0x0155, 0x0155, PVALID},
  {0x0156, 0x0156, DISALLOWED},
  {0x0157, 0x0157, PVALID},
  {0x0158, 0x0158, DISALLOWED},
  {0x0159, 0x0159, PVALID},
  {0x015A, 0x015A, DISALLOWED},
  {0x015B, 0x015B, PVALID},
  {0x015C, 0x015C, DISALLOWED},
  {0x015D, 0x015D, PVALID},
  {0x015E, 0x015E, DISALLOWED},
  {0x015F, 0x015F, PVALID},
  {0x0160, 0x0160, DISALLOWED},
  {0x0161, 0x0161, PVALID},
  {0x0162, 0x0162, DISALLOWED},
  {0x0163, 0x0163, PVALID},
  {0x0164, 0x0164, DISALLOWED},
  {0x0165, 0x0165, PVALID},
  {0x0166, 0x0166, DISALLOWED},
  {0x0167, 0x0167, PVALID},
  {0x0168, 0x0168, DISALLOWED},
  {0x0169, 0x0169, PVALID},
  {0x016A, 0x016A, DISALLOWED},
  {0x016B, 0x016B, PVALID},
  {0x016C, 0x016C, DISALLOWED},
  {0x016D, 0x016D, PVALID},
  {0x016E, 0x016E, DISALLOWED},
  {0x016F, 0x016F, PVALID},
  {0x0170, 0x0170, DISALLOWED},
  {0x0171, 0x0171, PVALID},
  {0x0172, 0x0172, DISALLOWED},
  {0x0173, 0x0173, PVALID},
  {0x0174, 0x0174, DISALLOWED},
  {0x0175, 0x0175, PVALID},
  {0x0176, 0x0176, DISALLOWED},
  {0x0177, 0x0177, PVALID},
  {0x0178, 0x0179, DISALLOWED},
  {0x017A, 0x017A, PVALID},
  {0x017B, 0x017B, DISALLOWED},
  {0x017C, 0x017C, PVALID},
  {0x017D, 0x017D, DISALLOWED},
  {0x017E, 0x017E, PVALID},
  {0x017F, 0x017F, DISALLOWED},
  {0x0180, 0x0180, PVALID},
  {0x0181, 0x0182, DISALLOWED},
  {0x0183, 0x0183, PVALID},
  {0x0184, 0x0184, DISALLOWED},
  {0x0185, 0x0185, PVALID},
  {0x0186, 0x0187, DISALLOWED},
  {0x0188, 0x0188, PVALID},
  {0x0189, 0x018B, DISALLOWED},
  {0x018C, 0x018D, PVALID},
  {0x018E, 0x0191, DISALLOWED},
  {0x0192, 0x0192, PVALID},
  {0x0193, 0x0194, DISALLOWED},
  {0x0195, 0x0195, PVALID},
  {0x0196, 0x0198, DISALLOWED},
  {0x0199, 0x019B, PVALID},
  {0x019C, 0x019D, DISALLOWED},
  {0x019E, 0x019E, PVALID},
  {0x019F, 0x01A0, DISALLOWED},
  {0x01A1, 0x01A1, PVALID},
  {0x01A2, 0x01A2, DISALLOWED},
  {0x01A3, 0x01A3, PVALID},
  {0x01A4, 0x01A4, DISALLOWED},
  {0x01A5, 0x01A5, PVALID},
  {0x01A6, 0x01A7, DISALLOWED},
  {0x01A8, 0x01A8, PVALID},
  {0x01A9, 0x01A9, DISALLOWED},
  {0x01AA, 0x01AB, PVALID},
  {0x01AC, 0x01AC, DISALLOWED},
  {0x01AD, 0x01AD, PVALID},
  {0x01AE, 0x01AF, DISALLOWED},
  {0x01B0, 0x01B0, PVALID},
  {0x01B1, 0x01B3, DISALLOWED},
  {0x01B4, 0x01B4, PVALID},
  {0x01B5, 0x01B5, DISALLOWED},
  {0x01B6, 0x01B6, PVALID},
  {0x01B7, 0x01B8, DISALLOWED},
  {0x01B9, 0x01BB, PVALID},
  {0x01BC, 0x01BC, DISALLOWED},
  {0x01BD, 0x01C3, PVALID},
  {0x01C4, 0x01CD, DISALLOWED},
  {0x01CE, 0x01CE, PVALID},
  {0x01CF, 0x01CF, DISALLOWED},
  {0x01D0, 0x01D0, PVALID},
  {0x01D1, 0x01D1, DISALLOWED},
  {0x01D2, 0x01D2, PVALID},
  {0x01D3, 0x01D3, DISALLOWED},
  {0x01D4, 0x01D4, PVALID},
  {0x01D5, 0x01D5, DISALLOWED},
  {0x01D6, 0x01D6, PVALID},
  {0x01D7, 0x01D7, DISALLOWED},
  {0x01D8, 0x01D8, PVALID},
  {0x01D9, 0x01D9, DISALLOWED},
  {0x01DA, 0x01DA, PVALID},
  {0x01DB, 0x01DB, DISALLOWED},
  {0x01DC, 0x01DD, PVALID},
  {0x01DE, 0x01DE, DISALLOWED},
  {0x01DF, 0x01DF, PVALID},
  {0x01E0, 0x01E0, DISALLOWED},
  {0x01E1, 0x01E1, PVALID},
  {0x01E2, 0x01E2, DISALLOWED},
  {0x01E3, 0x01E3, PVALID},
  {0x01E4, 0x01E4, DISALLOWED},
  {0x01E5, 0x01E5, PVALID},
  {0x01E6, 0x01E6, DISALLOWED},
  {0x01E7, 0x01E7, PVALID},
  {0x01E8, 0x01E8, DISALLOWED},
  {0x01E9, 0x01E9, PVALID},
  {0x01EA, 0x01EA, DISALLOWED},
  {0x01EB, 0x01EB, PVALID},
  {0x01EC, 0x01EC, DISALLOWED},
  {0x01ED, 0x01ED, PVALID},
  {0x01EE, 0x01EE, DISALLOWED},
  {0x01EF, 0x01F0, PVALID},
  {0x01F1, 0x01F4, DISALLOWED},
  {0x01F5, 0x01F5, PVALID},
  {0x01F6, 0x01F8, DISALLOWED},
  {0x01F9, 0x01F9, PVALID},
  {0x01FA, 0x01FA, DISALLOWED},
  {0x01FB, 0x01FB, PVALID},
  {0x01FC, 0x01FC, DISALLOWED},
  {0x01FD, 0x01FD, PVALID},
  {0x01FE, 0x01FE, DISALLOWED},
  {0x01FF, 0x01FF, PVALID},
  {0x0200, 0x0200, DISALLOWED},
  {0x0201, 0x0201, PVALID},
  {0x0202, 0x0202, DISALLOWED},
  {0x0203, 0x0203, PVALID},
  {0x0204, 0x0204, DISALLOWED},
  {0x0205, 0x0205, PVALID},
  {0x0206, 0x0206, DISALLOWED},
  {0x0207, 0x0207, PVALID},
  {0x0208, 0x0208, DISALLOWED},
  {0x0209, 0x0209, PVALID},
  {0x020A, 0x020A, DISALLOWED},
  {0x020B, 0x020B, PVALID},
  {0x020C, 0x020C, DISALLOWED},
  {0x020D, 0x020D, PVALID},
  {0x020E, 0x020E, DISALLOWED},
  {0x020F, 0x020F, PVALID},
  {0x0210, 0x0210, DISALLOWED},
  {0x0211, 0x0211, PVALID},
  {0x0212, 0x0212, DISALLOWED},
  {0x0213, 0x0213, PVALID},
  {0x0214, 0x0214, DISALLOWED},
  {0x0215, 0x0215, PVALID},
  {0x0216, 0x0216, DISALLOWED},
  {0x0217, 0x0217, PVALID},
  {0x0218, 0x0218, DISALLOWED},
  {0x0219, 0x0219, PVALID},
  {0x021A, 0x021A, DISALLOWED},
  {0x021B, 0x021B, PVALID},
  {0x021C, 0x021C, DISALLOWED},
  {0x021D, 0x021D, PVALID},
  {0x021E, 0x021E, DISALLOWED},
  {0x021F, 0x021F, PVALID},
  {0x0220, 0x0220, DISALLOWED},
  {0x0221, 0x0221, PVALID},
  {0x0222, 0x0222, DISALLOWED},
  {0x0223, 0x0223, PVALID},
  {0x0224, 0x0224, DISALLOWED},
  {0x0225, 0x0225, PVALID},
  {0x0226, 0x0226, DISALLOWED},
  {0x0227, 0x0227, PVALID},
  {0x0228, 0x0228, DISALLOWED},
  {0x0229, 0x0229, PVALID},
  {0x022A, 0x022A, DISALLOWED},
  {0x022B, 0x022B, PVALID},
  {0x022C, 0x022C, DISALLOWED},
  {0x022D, 0x022D, PVALID},
  {0x022E, 0x022E, DISALLOWED},
  {0x022F, 0x022F, PVALID},
  {0x0230, 0x0230, DISALLOWED},
  {0x0231, 0x0231, PVALID},
  {0x0232, 0x0232, DISALLOWED},
  {0x0233, 0x0239, PVALID},
  {0x023A, 0x023B, DISALLOWED},
  {0x023C, 0x023C, PVALID},
  {0x023D, 0x023E, DISALLOWED},
  {0x023F, 0x0240, PVALID},
  {0x0241, 0x0241, DISALLOWED},
  {0x0242, 0x0242, PVALID},
  {0x0243, 0x0246, DISALLOWED},
  {0x0247, 0x0247, PVALID},
  {0x0248, 0x0248, DISALLOWED},
  {0x0249, 0x0249, PVALID},
  {0x024A, 0x024A, DISALLOWED},
  {0x024B, 0x024B, PVALID},
  {0x024C, 0x024C, DISALLOWED},
  {0x024D, 0x024D, PVALID},
  {0x024E, 0x024E, DISALLOWED},
  {0x024F, 0x02AF, PVALID},
  {0x02B0, 0x02B8, DISALLOWED},
  {0x02B9, 0x02C1, PVALID},
  {0x02C2, 0x02C5, DISALLOWED},
  {0x02C6, 0x02D1, PVALID},
  {0x02D2, 0x02EB, DISALLOWED},
  {0x02EC, 0x02EC, PVALID},
  {0x02ED, 0x02ED, DISALLOWED},
  {0x02EE, 0x02EE, PVALID},
  {0x02EF, 0x02FF, DISALLOWED},
  {0x0300, 0x033F, PVALID},
  {0x0340, 0x0341, DISALLOWED},
  {0x0342, 0x0342, PVALID},
  {0x0343, 0x0345, DISALLOWED},
  {0x0346, 0x034E, PVALID},
  {0x034F, 0x034F, DISALLOWED},
  {0x0350, 0x036F, PVALID},
  {0x0370, 0x0370, DISALLOWED},
  {0x0371, 0x0371, PVALID},
  {0x0372, 0x0372, DISALLOWED},
  {0x0373, 0x0373, PVALID},
  {0x0374, 0x0374, DISALLOWED},
  {0x0375, 0x0375, CONTEXTO},
  {0x0376, 0x0376, DISALLOWED},
  {0x0377, 0x0377, PVALID},
  {0x037A, 0x037A, DISALLOWED},
  {0x037B, 0x037D, PVALID},
  {0x037E, 0x037F, DISALLOWED},
  {0x0384, 0x038A, DISALLOWED},
  {0x038C, 0x038C, DISALLOWED},
  {0x038E, 0x038F, DISALLOWED},
  {0x0390, 0x0390, PVALID},
  {0x0391, 0x03A1, DISALLOWED},
  {0x03A3, 0x03AB, DISALLOWED},
  {0x03AC, 0x03CE, PVALID},
  {0x03CF, 0x03D6, DISALLOWED},
  {0x03D7, 0x03D7, PVALID},
  {0x03D8, 0x03D8, DISALLOWED},
  {0x03D9, 0x03D9, PVALID},
  {0x03DA, 0x03DA, DISALLOWED},
  {0x03DB, 0x03DB, PVALID},
  {0x03DC, 0x03DC, DISALLOWED},
  {0x03DD, 0x03DD, PVALID},
  {0x03DE, 0x03DE, DISALLOWED},
  {0x03DF, 0x03DF, PVALID},
  {0x03E0, 0x03E0, DISALLOWED},
  {0x03E1, 0x03E1, PVALID},
  {0x03E2, 0x03E2, DISALLOWED},
  {0x03E3, 0x03E3, PVALID},
  {0x03E4, 0x03E4, DISALLOWED},
  {0x03E5, 0x03E5, PVALID},
  {0x03E6, 0x03E6, DISALLOWED},
  {0x03E7, 0x03E7, PVALID},
  {0x03E8, 0x03E8, DISALLOWED},
  {0x03E9, 0x03E9, PVALID},
  {0x03EA, 0x03EA, DISALLOWED},
  {0x03EB, 0x03EB, PVALID},
  {0x03EC, 0x03EC, DISALLOWED},
  {0x03ED, 0x03ED, PVALID},
  {0x03EE, 0x03EE, DISALLOWED},
  {0x03EF, 0x03EF, PVALID},
  {0x03F0, 0x03F2, DISALLOWED},
  {0x03F3, 0x03F3, PVALID},
  {0x03F4, 0x03F7, DISALLOWED},
  {0x03F8, 0x03F8, PVALID},
  {0x03F9, 0x03FA, DISALLOWED},
  {0x03FB, 0x03FC, PVALID},
  {0x03FD, 0x042F, DISALLOWED},
  {0x0430, 0x045F, PVALID},
  {0x0460, 0x0460, DISALLOWED},
  {0x0461, 0x0461, PVALID},
  {0x0462, 0x0462, DISALLOWED},
  {0x0463, 0x0463, PVALID},
  {0x0464, 0x0464, DISALLOWED},
  {0x0465, 0x0465, PVALID},
  {0x0466, 0x0466, DISALLOWED},
  {0x0467, 0x0467, PVALID},
  {0x0468, 0x0468, DISALLOWED},
  {0x0469, 0x0469, PVALID},
  {0x046A, 0x046A, DISALLOWED},
  {0x046B, 0x046B, PVALID},
  {0x046C, 0x046C, DISALLOWED},
  {0x046D, 0x046D, PVALID},
  {0x046E, 0x046E, DISALLOWED},
  {0x046F, 0x046F, PVALID},
  {0x0470, 0x0470, DISALLOWED},
  {0x0471, 0x0471, PVALID},
  {0x0472, 0x0472, DISALLOWED},
  {0x0473, 0x0473, PVALID},
  {0x0474, 0x0474, DISALLOWED},
  {0x0475, 0x0475, PVALID},
  {0x0476, 0x0476, DISALLOWED},
  {0x0477, 0x0477, PVALID},
  {0x0478, 0x0478, DISALLOWED},
  {0x0479, 0x0479, PVALID},
  {0x047A, 0x047A, DISALLOWED},
  {0x047B, 0x047B, PVALID},
  {0x047C, 0x047C, DISALLOWED},
  {0x047D, 0x047D, PVALID},
  {0x047E, 0x047E, DISALLOWED},
  {0x047F, 0x047F, PVALID},
  {0x0480, 0x0480, DISALLOWED},
  {0x0481, 0x0481, PVALID},
  {0x0482, 0x0482, DISALLOWED},
  {0x0483, 0x0487, PVALID},
  {0x0488, 0x048A, DISALLOWED},
  {0x048B, 0x048B, PVALID},
  {0x048C, 0x048C, DISALLOWED},
  {0x048D, 0x048D, PVALID},
  {0x048E, 0x048E, DISALLOWED},
  {0x048F, 0x048F, PVALID},
  {0x0490, 0x0490, DISALLOWED},
  {0x0491, 0x0491, PVALID},
  {0x0492, 0x0492, DISALLOWED},
  {0x0493, 0x0493, PVALID},
  {0x0494, 0x0494, DISALLOWED},
  {0x0495, 0x0495, PVALID},
  {0x0496, 0x0496, DISALLOWED},
  {0x0497, 0x0497, PVALID},
  {0x0498, 0x0498, DISALLOWED},
  {0x0499, 0x0499, PVALID},
  {0x049A, 0x049A, DISALLOWED},
  {0x049B, 0x049B, PVALID},
  {0x049C, 0x049C, DISALLOWED},
  {0x049D, 0x049D, PVALID},
  {0x049E, 0x049E, DISALLOWED},
  {0x049F, 0x049F, PVALID},
  {0x04A0, 0x04A0, DISALLOWED},
  {0x04A1, 0x04A1, PVALID},
  {0x04A2, 0x04A2, DISALLOWED},
  {0x04A3, 0x04A3, PVALID},
  {0x04A4, 0x04A4, DISALLOWED},
  {0x04A5, 0x04A5, PVALID},
  {0x04A6, 0x04A6, DISALLOWED},
  {0x04A7, 0x04A7, PVALID},
  {0x04A8, 0x04A8, DISALLOWED},
  {0x04A9, 0x04A9, PVALID},
  {0x04AA, 0x04AA, DISALLOWED},
  {0x04AB, 0x04AB, PVALID},
  {0x04AC, 0x04AC, DISALLOWED},
  {0x04AD, 0x04AD, PVALID},
  {0x04AE, 0x04AE, DISALLOWED},
  {0x04AF, 0x04AF, PVALID},
  {0x04B0, 0x04B0, DISALLOWED},
  {0x04B1, 0x04B1, PVALID},
  {0x04B2, 0x04B2, DISALLOWED},
  {0x04B3, 0x04B3, PVALID},
  {0x04B4, 0x04B4, DISALLOWED},
  {0x04B5, 0x04B5, PVALID},
  {0x04B6, 0x04B6, DISALLOWED},
  {0x04B7, 0x04B7, PVALID},
  {0x04B8, 0x04B8, DISALLOWED},
  {0x04B9, 0x04B9, PVALID},
  {0x04BA, 0x04BA, DISALLOWED},
  {0x04BB, 0x04BB, PVALID},
  {0x04BC, 0x04BC, DISALLOWED},
  {0x04BD, 0x04BD, PVALID},
  {0x04BE, 0x04BE, DISALLOWED},
  {0x04BF, 0x04BF, PVALID},
  {0x04C0, 0x04C1, DISALLOWED},
  {0x04C2, 0x04C2, PVALID},
  {0x04C3, 0x04C3, DISALLOWED},
  {0x04C4, 0x04C4, PVALID},
  {0x04C5, 0x04C5, DISALLOWED},
  {0x04C6, 0x04C6, PVALID},
  {0x04C7, 0x04C7, DISALLOWED},
  {0x04C8, 0x04C8, PVALID},
  {0x04C9, 0x04C9, DISALLOWED},
  {0x04CA, 0x04CA, PVALID},
  {0x04CB, 0x04CB, DISALLOWED},
  {0x04CC, 0x04CC, PVALID},
  {0x04CD, 0x04CD, DISALLOWED},
  {0x04CE, 0x04CF, PVALID},
  {0x04D0, 0x04D0, DISALLOWED},
  {0x04D1, 0x04D1, PVALID},
  {0x04D2, 0x04D2, DISALLOWED},
  {0x04D3, 0x04D3, PVALID},
  {0x04D4, 0x04D4, DISALLOWED},
  {0x04D5, 0x04D5, PVALID},
  {0x04D6, 0x04D6, DISALLOWED},
  {0x04D7, 0x04D7, PVALID},
  {0x04D8, 0x04D8, DISALLOWED},
  {0x04D9, 0x04D9, PVALID},
  {0x04DA, 0x04DA, DISALLOWED},
  {0x04DB, 0x04DB, PVALID},
  {0x04DC, 0x04DC, DISALLOWED},
  {0x04DD, 0x04DD, PVALID},
  {0x04DE, 0x04DE, DISALLOWED},
  {0x04DF, 0x04DF, PVALID},
  {0x04E0, 0x04E0, DISALLOWED},
  {0x04E1, 0x04E1, PVALID},
  {0x04E2, 0x04E2, DISALLOWED},
  {0x04E3, 0x04E3, PVALID},
  {0x04E4, 0x04E4, DISALLOWED},
  {0x04E5, 0x04E5, PVALID},
  {0x04E6, 0x04E6, DISALLOWED},
  {0x04E7, 0x04E7, PVALID},
  {0x04E8, 0x04E8, DISALLOWED},
  {0x04E9, 0x04E9, PVALID},
  {0x04EA, 0x04EA, DISALLOWED},
  {0x04EB, 0x04EB, PVALID},
  {0x04EC, 0x04EC, DISALLOWED},
  {0x04ED, 0x04ED, PVALID},
  {0x04EE, 0x04EE, DISALLOWED},
  {0x04EF, 0x04EF, PVALID},
  {0x04F0, 0x04F0, DISALLOWED},
  {0x04F1, 0x04F1, PVALID},
  {0x04F2, 0x04F2, DISALLOWED},
  {0x04F3, 0x04F3, PVALID},
  {0x04F4, 0x04F4, DISALLOWED},
  {0x04F5, 0x04F5, PVALID},
  {0x04F6, 0x04F6, DISALLOWED},
  {0x04F7, 0x04F7, PVALID},
  {0x04F8, 0x04F8, DISALLOWED},
  {0x04F9, 0x04F9, PVALID},
  {0x04FA, 0x04FA, DISALLOWED},
  {0x04FB, 0x04FB, PVALID},
  {0x04FC, 0x04FC, DISALLOWED},
  {0x04FD, 0x04FD, PVALID},
  {0x04FE, 0x04FE, DISALLOWED},
  {0x04FF, 0x04FF, PVALID},
  {0x0500, 0x0500, DISALLOWED},
  {0x0501, 0x0501, PVALID},
  {0x0502, 0x0502, DISALLOWED},
  {0x0503, 0x0503, PVALID},
  {0x0504, 0x0504, DISALLOWED},
  {0x0505, 0x0505, PVALID},
  {0x0506, 0x0506, DISALLOWED},
  {0x0507, 0x0507, PVALID},
  {0x0508, 0x0508, DISALLOWED},
  {0x0509, 0x0509, PVALID},
  {0x050A, 0x050A, DISALLOWED},
  {0x050B, 0x050B, PVALID},
  {0x050C, 0x050C, DISALLOWED},
  {0x050D, 0x050D, PVALID},
  {0x050E, 0x050E, DISALLOWED},
  {0x050F, 0x050F, PVALID},
  {0x0510, 0x0510, DISALLOWED},
  {0x0511, 0x0511, PVALID},
  {0x0512, 0x0512, DISALLOWED},
  {0x0513, 0x0513, PVALID},
  {0x0514, 0x0514, DISALLOWED},
  {0x0515, 0x0515, PVALID},
  {0x0516, 0x0516, DISALLOWED},
  {0x0517, 0x0517, PVALID},
  {0x0518, 0x0518, DISALLOWED},
  {0x0519, 0x0519, PVALID},
  {0x051A, 0x051A, DISALLOWED},
  {0x051B, 0x051B, PVALID},
  {0x051C, 0x051C, DISALLOWED},
  {0x051D, 0x051D, PVALID},
  {0x051E, 0x051E, DISALLOWED},
  {0x051F, 0x051F, PVALID},
  {0x0520, 0x0520, DISALLOWED},
  {0x0521, 0x0521, PVALID},
  {0x0522, 0x0522, DISALLOWED},
  {0x0523, 0x0523, PVALID},
  {0x0524, 0x0524, DISALLOWED},
  {0x0525, 0x0525, PVALID},
  {0x0526, 0x0526, DISALLOWED},
  {0x0527, 0x0527, PVALID},
  {0x0528, 0x0528, DISALLOWED},
  {0x0529, 0x0529, PVALID},
  {0x052A, 0x052A, DISALLOWED},
  {0x052B, 0x052B, PVALID},
  {0x052C, 0x052C, DISALLOWED},
  {0x052D, 0x052D, PVALID},
  {0x052E, 0x052E, DISALLOWED},
  {0x052F, 0x052F, PVALID},
  {0x0531, 0x0556, DISALLOWED},
  {0x0559, 0x0559, PVALID},
  {0x055A, 0x055F, DISALLOWED},
  {0x0560, 0x0586, PVALID},
  {0x0587, 0x0587, DISALLOWED},
  {0x0588, 0x0588, PVALID},
  {0x0589, 0x058A, DISALLOWED},
  {0x058D, 0x058F, DISALLOWED},
  {0x0591, 0x05BD, PVALID},
  {0x05BE, 0x05BE, DISALLOWED},
  {0x05BF, 0x05BF, PVALID},
  {0x05C0, 0x05C0, DISALLOWED},
  {0x05C1, 0x05C2, PVALID},
  {0x05C3, 0x05C3, DISALLOWED},
  {0x05C4, 0x05C5, PVALID},
  {0x05C6, 0x05C6, DISALLOWED},
  {0x05C7, 0x05C7, PVALID},
  {0x05D0, 0x05EA, PVALID},
  {0x05EF, 0x05F2, PVALID},
  {0x05F3, 0x05F4, CONTEXTO},
  {0x0600, 0x060F, DISALLOWED},
  {0x0610, 0x061A, PVALID},
  {0x061B, 0x061C, DISALLOWED},
  {0x061E, 0x061F, DISALLOWED},
  {0x0620, 0x063F, PVALID},
  {0x0640, 0x0640, DISALLOWED},
  {0x0641, 0x065F, PVALID},
  {0x0660, 0x0669, CONTEXTO},
  {0x066A, 0x066D, DISALLOWED},
  {0x066E, 0x0674, PVALID},
  {0x0675, 0x0678, DISALLOWED},
  {0x0679, 0x06D3, PVALID},
  {0x06D4, 0x06D4, DISALLOWED},
  {0x06D5, 0x06DC, PVALID},
  {0x06DD, 0x06DE, DISALLOWED},
  {0x06DF, 0x06E8, PVALID},
  {0x06E9, 0x06E9, DISALLOWED},
  {0x06EA, 0x06EF, PVALID},
  {0x06F0, 0x06F9, CONTEXTO},
  {0x06FA, 0x06FF, PVALID},
  {0x0700, 0x070D, DISALLOWED},
  {0x070F, 0x070F, DISALLOWED},
  {0x0710, 0x074A, PVALID},
  {0x074D, 0x07B1, PVALID},
  {0x07C0, 0x07F5, PVALID},
  {0x07F6, 0x07FA, DISALLOWED},
  {0x07FD, 0x07FD, PVALID},
  {0x07FE, 0x07FF, DISALLOWED},
  {0x0800, 0x082D, PVALID},
  {0x0830, 0x083E, DISALLOWED},
  {0x0840, 0x085B, PVALID},
  {0x085E, 0x085E, DISALLOWED},
  {0x0860, 0x086A, PVALID},
  {0x08A0, 0x08B4, PVALID},
  {0x08B6, 0x08BD, PVALID},
  {0x08D3, 0x08E1, PVALID},
  {0x08E2, 0x08E2, DISALLOWED},
  {0x08E3, 0x0957, PVALID},
  {0x0958, 0x095F, DISALLOWED},
  {0x0960, 0x0963, PVALID},
  {0x0964, 0x0965, DISALLOWED},
  {0x0966, 0x096F, PVALID},
  {0x0970, 0x0970, DISALLOWED},
  {0x0971, 0x0983, PVALID},
  {0x0985, 0x098C, PVALID},
  {0x098F, 0x0990, PVALID},
  {0x0993, 0x09A8, PVALID},
  {0x09AA, 0x09B0, PVALID},
  {0x09B2, 0x09B2, PVALID},
  {0x09B6, 0x09B9, PVALID},
  {0x09BC, 0x09C4, PVALID},
  {0x09C7, 0x09C8, PVALID},
  {0x09CB, 0x09CE, PVALID},
  {0x09D7, 0x09D7, PVALID},
  {0x09DC, 0x09DD, DISALLOWED},
  {0x09DF, 0x09DF, DISALLOWED},
  {0x09E0, 0x09E3, PVALID},
  {0x09E6, 0x09F1, PVALID},
  {0x09F2, 0x09FB, DISALLOWED},
  {0x09FC, 0x09FC, PVALID},
  {0x09FD, 0x09FD, DISALLOWED},
  {0x09FE, 0x09FE, PVALID},
  {0x0A01, 0x0A03, PVALID},
  {0x0A05, 0x0A0A, PVALID},
  {0x0A0F, 0x0A10, PVALID},
  {0x0A13, 0x0A28, PVALID},
  {0x0A2A, 0x0A30, PVALID},
  {0x0A32, 0x0A32, PVALID},
  {0x0A33, 0x0A33, DISALLOWED},
  {0x0A35, 0x0A35, PVALID},
  {0x0A36, 0x0A36, DISALLOWED},
  {0x0A38, 0x0A39, PVALID},
  {0x0A3C, 0x0A3C, PVALID},
  {0x0A3E, 0x0A42, PVALID},
  {0x0A47, 0x0A48, PVALID},
  {0x0A4B, 0x0A4D, PVALID},
  {0x0A51, 0x0A51, PVALID},
  {0x0A59, 0x0A5B, DISALLOWED},
  {0x0A5C, 0x0A5C, PVALID},
  {0x0A5E, 0x0A5E, DISALLOWED},
  {0x0A66, 0x0A75, PVALID},
  {0x0A76, 0x0A76, DISALLOWED},
  {0x0A81, 0x0A83, PVALID},
  {0x0A85, 0x0A8D, PVALID},
  {0x0A8F, 0x0A91, PVALID},
  {0x0A93, 0x0AA8, PVALID},
  {0x0AAA, 0x0AB0, PVALID},
  {0x0AB2, 0x0AB3, PVALID},
  {0x0AB5, 0x0AB9, PVALID},
  {0x0ABC, 0x0AC5, PVALID},
  {0x0AC7, 0x0AC9, PVALID},
  {0x0ACB, 0x0ACD, PVALID},
  {0x0AD0, 0x0AD0, PVALID},
  {0x0AE0, 0x0AE3, PVALID},
  {0x0AE6, 0x0AEF, PVALID},
  {0x0AF0, 0x0AF1, DISALLOWED},
  {0x0AF9, 0x0AFF, PVALID},
  {0x0B01, 0x0B03, PVALID},
  {0x0B05, 0x0B0C, PVALID},
  {0x0B0F, 0x0B10, PVALID},
  {0x0B13, 0x0B28, PVALID},
  {0x0B2A, 0x0B30, PVALID},
  {0x0B32, 0x0B33, PVALID},
  {0x0B35, 0x0B39, PVALID},
  {0x0B3C, 0x0B44, PVALID},
  {0x0B47, 0x0B48, PVALID},
  {0x0B4B, 0x0B4D, PVALID},
  {0x0B56, 0x0B57, PVALID},
  {0x0B5C, 0x0B5D, DISALLOWED},
  {0x0B5F, 0x0B63, PVALID},
  {0x0B66, 0x0B6F, PVALID},
  {0x0B70, 0x0B70, DISALLOWED},
  {0x0B71, 0x0B71, PVALID},
  {0x0B72, 0x0B77, DISALLOWED},
  {0x0B82, 0x0B83, PVALID},
  {0x0B85, 0x0B8A, PVALID},
  {0x0B8E, 0x0B90, PVALID},
  {0x0B92, 0x0B95, PVALID},
  {0x0B99, 0x0B9A, PVALID},
  {0x0B9C, 0x0B9C, PVALID},
  {0x0B9E, 0x0B9F, PVALID},
  {0x0BA3, 0x0BA4, PVALID},
  {0x0BA8, 0x0BAA, PVALID},
  {0x0BAE, 0x0BB9, PVALID},
  {0x0BBE, 0x0BC2, PVALID},
  {0x0BC6, 0x0BC8, PVALID},
  {0x0BCA, 0x0BCD, PVALID},
  {0x0BD0, 0x0BD0, PVALID},
  {0x0BD7, 0x0BD7, PVALID},
  {0x0BE6, 0x0BEF, PVALID},
  {0x0BF0, 0x0BFA, DISALLOWED},
  {0x0C00, 0x0C0C, PVALID},
  {0x0C0E, 0x0C10, PVALID},
  {0x0C12, 0x0C28, PVALID},
  {0x0C2A, 0x0C39, PVALID},
  {0x0C3D, 0x0C44, PVALID},
  {0x0C46, 0x0C48, PVALID},
  {0x0C4A, 0x0C4D, PVALID},
  {0x0C55, 0x0C56, PVALID},
  {0x0C58, 0x0C5A, PVALID},
  {0x0C60, 0x0C63, PVALID},
  {0x0C66, 0x0C6F, PVALID},
  {0x0C77, 0x0C7F, DISALLOWED},
  {0x0C80, 0x0C83, PVALID},
  {0x0C84, 0x0C84, DISALLOWED},
  {0x0C85, 0x0C8C, PVALID},
  {0x0C8E, 0x0C90, PVALID},
  {0x0C92, 0x0CA8, PVALID},
  {0x0CAA, 0x0CB3, PVALID},
  {0x0CB5, 0x0CB9, PVALID},
  {0x0CBC, 0x0CC4, PVALID},
  {0x0CC6, 0x0CC8, PVALID},
  {0x0CCA, 0x0CCD, PVALID},
  {0x0CD5, 0x0CD6, PVALID},
  {0x0CDE, 0x0CDE, PVALID},
  {0x0CE0, 0x0CE3, PVALID},
  {0x0CE6, 0x0CEF, PVALID},
  {0x0CF1, 0x0CF2, PVALID},
  {0x0D00, 0x0D03, PVALID},
  {0x0D05, 0x0D0C, PVALID},
  {0x0D0E, 0x0D10, PVALID},
  {0x0D12, 0x0D44, PVALID},
  {0x0D46, 0x0D48, PVALID},
  {0x0D4A, 0x0D4E, PVALID},
  {0x0D4F, 0x0D4F, DISALLOWED},
  {0x0D54, 0x0D57, PVALID},
  {0x0D58, 0x0D5E, DISALLOWED},
  {0x0D5F, 0x0D63, PVALID},
  {0x0D66, 0x0D6F, PVALID},
  {0x0D70, 0x0D79, DISALLOWED},
  {0x0D7A, 0x0D7F, PVALID},
  {0x0D82, 0x0D83, PVALID},
  {0x0D85, 0x0D96, PVALID},
  {0x0D9A, 0x0DB1, PVALID},
  {0x0DB3, 0x0DBB, PVALID},
  {0x0DBD, 0x0DBD, PVALID},
  {0x0DC0, 0x0DC6, PVALID},
  {0x0DCA, 0x0DCA, PVALID},
  {0x0DCF, 0x0DD4, PVALID},
  {0x0DD6, 0x0DD6, PVALID},
  {0x0DD8, 0x0DDF, PVALID},
  {0x0DE6, 0x0DEF, PVALID},
  {0x0DF2, 0x0DF3, PVALID},
  {0x0DF4, 0x0DF4, DISALLOWED},
  {0x0E01, 0x0E32, PVALID},
  {0x0E33, 0x0E33, DISALLOWED},
  {0x0E34, 0x0E3A, PVALID},
  {0x0E3F, 0x0E3F, DISALLOWED},
  {0x0E40, 0x0E4E, PVALID},
  {0x0E4F, 0x0E4F, DISALLOWED},
  {0x0E50, 0x0E59, PVALID},
  {0x0E5A, 0x0E5B, DISALLOWED},
  {0x0E81, 0x0E82, PVALID},
  {0x0E84, 0x0E84, PVALID},
  {0x0E86, 0x0E8A, PVALID},
  {0x0E8C, 0x0EA3, PVALID},
  {0x0EA5, 0x0EA5, PVALID},
  {0x0EA7, 0x0EB2, PVALID},
  {0x0EB3, 0x0EB3, DISALLOWED},
  {0x0EB4, 0x0EBD, PVALID},
  {0x0EC0, 0x0EC4, PVALID},
  {0x0EC6, 0x0EC6, PVALID},
  {0x0EC8, 0x0ECD, PVALID},
  {0x0ED0, 0x0ED9, PVALID},
  {0x0EDC, 0x0EDD, DISALLOWED},
  {0x0EDE, 0x0EDF, PVALID},
  {0x0F00, 0x0F00, PVALID},
  {0x0F01, 0x0F0A, DISALLOWED},
  {0x0F0B, 0x0F0B, PVALID},
  {0x0F0C, 0x0F17, DISALLOWED},
  {0x0F18, 0x0F19, PVALID},
  {0x0F1A, 0x0F1F, DISALLOWED},
  {0x0F20, 0x0F29, PVALID},
  {0x0F2A, 0x0F34, DISALLOWED},
  {0x0F35, 0x0F35, PVALID},
  {0x0F36, 0x0F36, DISALLOWED},
  {0x0F37, 0x0F37, PVALID},
  {0x0F38, 0x0F38, DISALLOWED},
  {0x0F39, 0x0F39, PVALID},
  {0x0F3A, 0x0F3D, DISALLOWED},
  {0x0F3E, 0x0F42, PVALID},
  {0x0F43, 0x0F43, DISALLOWED},
  {0x0F44, 0x0F47, PVALID},
  {0x0F49, 0x0F4C, PVALID},
  {0x0F4D, 0x0F4D, DISALLOWED},
  {0x0F4E, 0x0F51, PVALID},
  {0x0F52, 0x0F52, DISALLOWED},
  {0x0F53, 0x0F56, PVALID},
  {0x0F57, 0x0F57, DISALLOWED},
  {0x0F58, 0x0F5B, PVALID},
  {0x0F5C, 0x0F5C, DISALLOWED},
  {0x0F5D, 0x0F68, PVALID},
  {0x0F69, 0x0F69, DISALLOWED},
  {0x0F6A, 0x0F6C, PVALID},
  {0x0F71, 0x0F72, PVALID},
  {0x0F73, 0x0F73, DISALLOWED},
  {0x0F74, 0x0F74, PVALID},
  {0x0F75, 0x0F79, DISALLOWED},
  {0x0F7A, 0x0F80, PVALID},
  {0x0F81, 0x0F81, DISALLOWED},
  {0x0F82, 0x0F84, PVALID},
  {0x0F85, 0x0F85, DISALLOWED},
  {0x0F86, 0x0F92, PVALID},
  {0x0F93, 0x0F93, DISALLOWED},
  {0x0F94, 0x0F97, PVALID},
  {0x0F99, 0x0F9C, PVALID},
  {0x0F9D, 0x0F9D, DISALLOWED},
  {0x0F9E, 0x0FA1, PVALID},
  {0x0FA2, 0x0FA2, DISALLOWED},
  {0x0FA3, 0x0FA6, PVALID},
  {0x0FA7, 0x0FA7, DISALLOWED},
  {0x0FA8, 0x0FAB, PVALID},
  {0x0FAC, 0x0FAC, DISALLOWED},
  {0x0FAD, 0x0FB8, PVALID},
  {0x0FB9, 0x0FB9, DISALLOWED},
  {0x0FBA, 0x0FBC, PVALID},
  {0x0FBE, 0x0FC5, DISALLOWED},
  {0x0FC6, 0x0FC6, PVALID},
  {0x0FC7, 0x0FCC, DISALLOWED},
  {0x0FCE, 0x0FDA, DISALLOWED},
  {0x1000, 0x1049, PVALID},
  {0x104A, 0x104F, DISALLOWED},
  {0x1050, 0x109D, PVALID},
  {0x109E, 0x10C5, DISALLOWED},
  {0x10C7, 0x10C7, DISALLOWED},
  {0x10CD, 0x10CD, DISALLOWED},
  {0x10D0, 0x10FA, PVALID},
  {0x10FB, 0x10FC, DISALLOWED},
  {0x10FD, 0x10FF, PVALID},
  {0x1100, 0x11FF, DISALLOWED},
  {0x1200, 0x1248, PVALID},
  {0x124A, 0x124D, PVALID},
  {0x1250, 0x1256, PVALID},
  {0x1258, 0x1258, PVALID},
  {0x125A, 0x125D, PVALID},
  {0x1260, 0x1288, PVALID},
  {0x128A, 0x128D, PVALID},
  {0x1290, 0x12B0, PVALID},
  {0x12B2, 0x12B5, PVALID},
  {0x12B8, 0x12BE, PVALID},
  {0x12C0, 0x12C0, PVALID},
  {0x12C2, 0x12C5, PVALID},
  {0x12C8, 0x12D6, PVALID},
  {0x12D8, 0x1310, PVALID},
  {0x1312, 0x1315, PVALID},
  {0x1318, 0x135A, PVALID},
  {0x135D, 0x135F, PVALID},
  {0x1360, 0x137C, DISALLOWED},
  {0x1380, 0x138F, PVALID},
  {0x1390, 0x1399, DISALLOWED},
  {0x13A0, 0x13F5, PVALID},
  {0x13F8, 0x13FD, DISALLOWED},
  {0x1400, 0x1400, DISALLOWED},
  {0x1401, 0x166C, PVALID},
  {0x166D, 0x166E, DISALLOWED},
  {0x166F, 0x167F, PVALID},
  {0x1680, 0x1680, DISALLOWED},
  {0x1681, 0x169A, PVALID},
  {0x169B, 0x169C, DISALLOWED},
  {0x16A0, 0x16EA, PVALID},
  {0x16EB, 0x16F0, DISALLOWED},
  {0x16F1, 0x16F8, PVALID},
  {0x1700, 0x170C, PVALID},
  {0x170E, 0x1714, PVALID},
  {0x1720, 0x1734, PVALID},
  {0x1735, 0x1736, DISALLOWED},
  {0x1740, 0x1753, PVALID},
  {0x1760, 0x176C, PVALID},
  {0x176E, 0x1770, PVALID},
  {0x1772, 0x1773, PVALID},
  {0x1780, 0x17B3, PVALID},
  {0x17B4, 0x17B5, DISALLOWED},
  {0x17B6, 0x17D3, PVALID},
  {0x17D4, 0x17D6, DISALLOWED},
  {0x17D7, 0x17D7, PVALID},
  {0x17D8, 0x17DB, DISALLOWED},
  {0x17DC, 0x17DD, PVALID},
  {0x17E0, 0x17E9, PVALID},
  {0x17F0, 0x17F9, DISALLOWED},
  {0x1800, 0x180E, DISALLOWED},
  {0x1810, 0x1819, PVALID},
  {0x1820, 0x1878, PVALID},
  {0x1880, 0x18AA, PVALID},
  {0x18B0, 0x18F5, PVALID},
  {0x1900, 0x191E, PVALID},
  {0x1920, 0x192B, PVALID},
  {0x1930, 0x193B, PVALID},
  {0x1940, 0x1940, DISALLOWED},
  {0x1944, 0x1945, DISALLOWED},
  {0x1946, 0x196D, PVALID},
  {0x1970, 0x1974, PVALID},
  {0x1980, 0x19AB, PVALID},
  {0x19B0, 0x19C9, PVALID},
  {0x19D0, 0x19D9, PVALID},
  {0x19DA, 0x19DA, DISALLOWED},
  {0x19DE, 0x19FF, DISALLOWED},
  {0x1A00, 0x1A1B, PVALID},
  {0x1A1E, 0x1A1F, DISALLOWED},
  {0x1A20, 0x1A5E, PVALID},
  {0x1A60, 0x1A7C, PVALID},
  {0x1A7F, 0x1A89, PVALID},
  {0x1A90, 0x1A99, PVALID},
  {0x1AA0, 0x1AA6, DISALLOWED},
  {0x1AA7, 0x1AA7, PVALID},
  {0x1AA8, 0x1AAD, DISALLOWED},
  {0x1AB0, 0x1ABD, PVALID},
  {0x1ABE, 0x1ABE, DISALLOWED},
  {0x1B00, 0x1B4B, PVALID},
  {0x1B50, 0x1B59, PVALID},
  {0x1B5A, 0x1B6A, DISALLOWED},
  {0x1B6B, 0x1B73, PVALID},
  {0x1B74, 0x1B7C, DISALLOWED},
  {0x1B80, 0x1BF3, PVALID},
  {0x1BFC, 0x1BFF, DISALLOWED},
  {0x1C00, 0x1C37, PVALID},
  {0x1C3B, 0x1C3F, DISALLOWED},
  {0x1C40, 0x1C49, PVALID},
  {0x1C4D, 0x1C7D, PVALID},
  {0x1C7E, 0x1C88, DISALLOWED},
  {0x1C90, 0x1CBA, DISALLOWED},
  {0x1CBD, 0x1CC7, DISALLOWED},
  {0x1CD0, 0x1CD2, PVALID},
  {0x1CD3, 0x1CD3, DISALLOWED},
  {0x1CD4, 0x1CFA, PVALID},
  {0x1D00, 0x1D2B, PVALID},
  {0x1D2C, 0x1D2E, DISALLOWED},
  {0x1D2F, 0x1D2F, PVALID},
  {0x1D30, 0x1D3A, DISALLOWED},
  {0x1D3B, 0x1D3B, PVALID},
  {0x1D3C, 0x1D4D, DISALLOWED},
  {0x1D4E, 0x1D4E, PVALID},
  {0x1D4F, 0x1D6A, DISALLOWED},
  {0x1D6B, 0x1D77, PVALID},
  {0x1D78, 0x1D78, DISALLOWED},
  {0x1D79, 0x1D9A, PVALID},
  {0x1D9B, 0x1DBF, DISALLOWED},
  {0x1DC0, 0x1DF9, PVALID},
  {0x1DFB, 0x1DFF, PVALID},
  {0x1E00, 0x1E00, DISALLOWED},
  {0x1E01, 0x1E01, PVALID},
  {0x1E02, 0x1E02, DISALLOWED},
  {0x1E03, 0x1E03, PVALID},
  {0x1E04, 0x1E04, DISALLOWED},
  {0x1E05, 0x1E05, PVALID},
  {0x1E06, 0x1E06, DISALLOWED},
  {0x1E07, 0x1E07, PVALID},
  {0x1E08, 0x1E08, DISALLOWED},
  {0x1E09, 0x1E09, PVALID},
  {0x1E0A, 0x1E0A, DISALLOWED},
  {0x1E0B, 0x1E0B, PVALID},
  {0x1E0C, 0x1E0C, DISALLOWED},
  {0x1E0D, 0x1E0D, PVALID},
  {0x1E0E, 0x1E0E, DISALLOWED},
  {0x1E0F, 0x1E0F, PVALID},
  {0x1E10, 0x1E10, DISALLOWED},
  {0x1E11, 0x1E11, PVALID},
  {0x1E12, 0x1E12, DISALLOWED},
  {0x1E13, 0x1E13, PVALID},
  {0x1E14, 0x1E14, DISALLOWED},
  {0x1E15, 0x1E15, PVALID},
  {0x1E16, 0x1E16, DISALLOWED},
  {0x1E17, 0x1E17, PVALID},
  {0x1E18, 0x1E18, DISALLOWED},
  {0x1E19, 0x1E19, PVALID},
  {0x1E1A, 0x1E1A, DISALLOWED},
  {0x1E1B, 0x1E1B, PVALID},
  {0x1E1C, 0x1E1C, DISALLOWED},
  {0x1E1D, 0x1E1D, PVALID},
  {0x1E1E, 0x1E1E, DISALLOWED},
  {0x1E1F, 0x1E1F, PVALID},
  {0x1E20, 0x1E20, DISALLOWED},
  {0x1E21, 0x1E21, PVALID},
  {0x1E22, 0x1E22, DISALLOWED},
  {0x1E23, 0x1E23, PVALID},
  {0x1E24, 0x1E24, DISALLOWED},
  {0x1E25, 0x1E25, PVALID},
  {0x1E26, 0x1E26, DISALLOWED},
  {0x1E27, 0x1E27, PVALID},
  {0x1E28, 0x1E28, DISALLOWED},
  {0x1E29, 0x1E29, PVALID},
  {0x1E2A, 0x1E2A, DISALLOWED},
  {0x1E2B, 0x1E2B, PVALID},
  {0x1E2C, 0x1E2C, DISALLOWED},
  {0x1E2D, 0x1E2D, PVALID},
  {0x1E2E, 0x1E2E, DISALLOWED},
  {0x1E2F, 0x1E2F, PVALID},
  {0x1E30, 0x1E30, DISALLOWED},
  {0x1E31, 0x1E31, PVALID},
  {0x1E32, 0x1E32, DISALLOWED},
  {0x1E33, 0x1E33, PVALID},
  {0x1E34, 0x1E34, DISALLOWED},
  {0x1E35, 0x1E35, PVALID},
  {0x1E36, 0x1E36, DISALLOWED},
  {0x1E37, 0x1E37, PVALID},
  {0x1E38, 0x1E38, DISALLOWED},
  {0x1E39, 0x1E39, PVALID},
  {0x1E3A, 0x1E3A, DISALLOWED},
  {0x1E3B, 0x1E3B, PVALID},
  {0x1E3C, 0x1E3C, DISALLOWED},
  {0x1E3D, 0x1E3D, PVALID},
  {0x1E3E, 0x1E3E, DISALLOWED},
  {0x1E3F, 0x1E3F, PVALID},
  {0x1E40, 0x1E40, DISALLOWED},
  {0x1E41, 0x1E41, PVALID},
  {0x1E42, 0x1E42, DISALLOWED},
  {0x1E43, 0x1E43, PVALID},
  {0x1E44, 0x1E44, DISALLOWED},
  {0x1E45, 0x1E45, PVALID},
  {0x1E46, 0x1E46, DISALLOWED},
  {0x1E47, 0x1E47, PVALID},
  {0x1E48, 0x1E48, DISALLOWED},
  {0x1E49, 0x1E49, PVALID},
  {0x1E4A, 0x1E4A, DISALLOWED},
  {0x1E4B, 0x1E4B, PVALID},
  {0x1E4C, 0x1E4C, DISALLOWED},
  {0x1E4D, 0x1E4D, PVALID},
  {0x1E4E, 0x1E4E, DISALLOWED},
  {0x1E4F, 0x1E4F, PVALID},
  {0x1E50, 0x1E50, DISALLOWED},
  {0x1E51, 0x1E51, PVALID},
  {0x1E52, 0x1E52, DISALLOWED},
  {0x1E53, 0x1E53, PVALID},
  {0x1E54, 0x1E54, DISALLOWED},
  {0x1E55, 0x1E55, PVALID},
  {0x1E56, 0x1E56, DISALLOWED},
  {0x1E57, 0x1E57, PVALID},
  {0x1E58, 0x1E58, DISALLOWED},
  {0x1E59, 0x1E59, PVALID},
  {0x1E5A, 0x1E5A, DISALLOWED},
  {0x1E5B, 0x1E5B, PVALID},
  {0x1E5C, 0x1E5C, DISALLOWED},
  {0x1E5D, 0x1E5D, PVALID},
  {0x1E5E, 0x1E5E, DISALLOWED},
  {0x1E5F, 0x1E5F, PVALID},
  {0x1E60, 0x1E60, DISALLOWED},
  {0x1E61, 0x1E61, PVALID},
  {0x1E62, 0x1E62, DISALLOWED},
  {0x1E63, 0x1E63, PVALID},
  {0x1E64, 0x1E64, DISALLOWED},
  {0x1E65, 0x1E65, PVALID},
  {0x1E66, 0x1E66, DISALLOWED},
  {0x1E67, 0x1E67, PVALID},
  {0x1E68, 0x1E68, DISALLOWED},
  {0x1E69, 0x1E69, PVALID},
  {0x1E6A, 0x1E6A, DISALLOWED},
  {0x1E6B, 0x1E6B, PVALID},
  {0x1E6C, 0x1E6C, DISALLOWED},
  {0x1E6D, 0x1E6D, PVALID},
  {0x1E6E, 0x1E6E, DISALLOWED},
  {0x1E6F, 0x1E6F, PVALID},
  {0x1E70, 0x1E70, DISALLOWED},
  {0x1E71, 0x1E71, PVALID},
  {0x1E72, 0x1E72, DISALLOWED},
  {0x1E73, 0x1E73, PVALID},
  {0x1E74, 0x1E74, DISALLOWED},
  {0x1E75, 0x1E75, PVALID},
  {0x1E76, 0x1E76, DISALLOWED},
  {0x1E77, 0x1E77, PVALID},
  {0x1E78, 0x1E78, DISALLOWED},
  {0x1E79, 0x1E79, PVALID},
  {0x1E7A, 0x1E7A, DISALLOWED},
  {0x1E7B, 0x1E7B, PVALID},
  {0x1E7C, 0x1E7C, DISALLOWED},
  {0x1E7D, 0x1E7D, PVALID},
  {0x1E7E, 0x1E7E, DISALLOWED},
  {0x1E7F, 0x1E7F, PVALID},
  {0x1E80, 0x1E80, DISALLOWED},
  {0x1E81, 0x1E81, PVALID},
  {0x1E82, 0x1E82, DISALLOWED},
  {0x1E83, 0x1E83, PVALID},
  {0x1E84, 0x1E84, DISALLOWED},
  {0x1E85, 0x1E85, PVALID},
  {0x1E86, 0x1E86, DISALLOWED},
  {0x1E87, 0x1E87, PVALID},
  {0x1E88, 0x1E88, DISALLOWED},
  {0x1E89, 0x1E89, PVALID},
  {0x1E8A, 0x1E8A, DISALLOWED},
  {0x1E8B, 0x1E8B, PVALID},
  {0x1E8C, 0x1E8C, DISALLOWED},
  {0x1E8D, 0x1E8D, PVALID},
  {0x1E8E, 0x1E8E, DISALLOWED},
  {0x1E8F, 0x1E8F, PVALID},
  {0x1E90, 0x1E90, DISALLOWED},
  {0x1E91, 0x1E91, PVALID},
  {0x1E92, 0x1E92, DISALLOWED},
  {0x1E93, 0x1E93, PVALID},
  {0x1E94, 0x1E94, DISALLOWED},
  {0x1E95, 0x1E99, PVALID},
  {0x1E9A, 0x1E9B, DISALLOWED},
  {0x1E9C, 0x1E9D, PVALID},
  {0x1E9E, 0x1E9E, DISALLOWED},
  {0x1E9F, 0x1E9F, PVALID},
  {0x1EA0, 0x1EA0, DISALLOWED},
  {0x1EA1, 0x1EA1, PVALID},
  {0x1EA2, 0x1EA2, DISALLOWED},
  {0x1EA3, 0x1EA3, PVALID},
  {0x1EA4, 0x1EA4, DISALLOWED},
  {0x1EA5, 0x1EA5, PVALID},
  {0x1EA6, 0x1EA6, DISALLOWED},
  {0x1EA7, 0x1EA7, PVALID},
  {0x1EA8, 0x1EA8, DISALLOWED},
  {0x1EA9, 0x1EA9, PVALID},
  {0x1EAA, 0x1EAA, DISALLOWED},
  {0x1EAB, 0x1EAB, PVALID},
  {0x1EAC, 0x1EAC, DISALLOWED},
  {0x1EAD, 0x1EAD, PVALID},
  {0x1EAE, 0x1EAE, DISALLOWED},
  {0x1EAF, 0x1EAF, PVALID},
  {0x1EB0, 0x1EB0, DISALLOWED},
  {0x1EB1, 0x1EB1, PVALID},
  {0x1EB2, 0x1EB2, DISALLOWED},
  {0x1EB3, 0x1EB3, PVALID},
  {0x1EB4, 0x1EB4, DISALLOWED},
  {0x1EB5, 0x1EB5, PVALID},
  {0x1EB6, 0x1EB6, DISALLOWED},
  {0x1EB7, 0x1EB7, PVALID},
  {0x1EB8, 0x1EB8, DISALLOWED},
  {0x1EB9, 0x1EB9, PVALID},
  {0x1EBA, 0x1EBA, DISALLOWED},
  {0x1EBB, 0x1EBB, PVALID},
  {0x1EBC, 0x1EBC, DISALLOWED},
  {0x1EBD, 0x1EBD, PVALID},
  {0x1EBE, 0x1EBE, DISALLOWED},
  {0x1EBF, 0x1EBF, PVALID},
  {0x1EC0, 0x1EC0, DISALLOWED},
  {0x1EC1, 0x1EC1, PVALID},
  {0x1EC2, 0x1EC2, DISALLOWED},
  {0x1EC3, 0x1EC3, PVALID},
  {0x1EC4, 0x1EC4, DISALLOWED},
  {0x1EC5, 0x1EC5, PVALID},
  {0x1EC6, 0x1EC6, DISALLOWED},
  {0x1EC7, 0x1EC7, PVALID},
  {0x1EC8, 0x1EC8, DISALLOWED},
  {0x1EC9, 0x1EC9, PVALID},
  {0x1ECA, 0x1ECA, DISALLOWED},
  {0x1ECB, 0x1ECB, PVALID},
  {0x1ECC, 0x1ECC, DISALLOWED},
  {0x1ECD, 0x1ECD, PVALID},
  {0x1ECE, 0x1ECE, DISALLOWED},
  {0x1ECF, 0x1ECF, PVALID},
  {0x1ED0, 0x1ED0, DISALLOWED},
  {0x1ED1, 0x1ED1, PVALID},
  {0x1ED2, 0x1ED2, DISALLOWED},
  {0x1ED3, 0x1ED3, PVALID},
  {0x1ED4, 0x1ED4, DISALLOWED},
  {0x1ED5, 0x1ED5, PVALID},
  {0x1ED6, 0x1ED6, DISALLOWED},
  {0x1ED7, 0x1ED7, PVALID},
  {0x1ED8, 0x1ED8, DISALLOWED},
  {0x1ED9, 0x1ED9, PVALID},
  {0x1EDA, 0x1EDA, DISALLOWED},
  {0x1EDB, 0x1EDB, PVALID},
  {0x1EDC, 0x1EDC, DISALLOWED},
  {0x1EDD, 0x1EDD, PVALID},
  {0x1EDE, 0x1EDE, DISALLOWED},
  {0x1EDF, 0x1EDF, PVALID},
  {0x1EE0, 0x1EE0, DISALLOWED},
  {0x1EE1, 0x1EE1, PVALID},
  {0x1EE2, 0x1EE2, DISALLOWED},
  {0x1EE3, 0x1EE3, PVALID},
  {0x1EE4, 0x1EE4, DISALLOWED},
  {0x1EE5, 0x1EE5, PVALID},
  {0x1EE6, 0x1EE6, DISALLOWED},
  {0x1EE7, 0x1EE7, PVALID},
  {0x1EE8, 0x1EE8, DISALLOWED},
  {0x1EE9, 0x1EE9, PVALID},
  {0x1EEA, 0x1EEA, DISALLOWED},
  {0x1EEB, 0x1EEB, PVALID},
  {0x1EEC, 0x1EEC, DISALLOWED},
  {0x1EED, 0x1EED, PVALID},
  {0x1EEE, 0x1EEE, DISALLOWED},
  {0x1EEF, 0x1EEF, PVALID},
  {0x1EF0, 0x1EF0, DISALLOWED},
  {0x1EF1, 0x1EF1, PVALID},
  {0x1EF2, 0x1EF2, DISALLOWED},
  {0x1EF3, 0x1EF3, PVALID},
  {0x1EF4, 0x1EF4, DISALLOWED},
  {0x1EF5, 0x1EF5, PVALID},
  {0x1EF6, 0x1EF6, DISALLOWED},
  {0x1EF7, 0x1EF7, PVALID},
  {0x1EF8, 0x1EF8, DISALLOWED},
  {0x1EF9, 0x1EF9, PVALID},
  {0x1EFA, 0x1EFA, DISALLOWED},
  {0x1EFB, 0x1EFB, PVALID},
  {0x1EFC, 0x1EFC, DISALLOWED},
  {0x1EFD, 0x1EFD, PVALID},
  {0x1EFE, 0x1EFE, DISALLOWED},
  {0x1EFF, 0x1F07, PVALID},
  {0x1F08, 0x1F0F, DISALLOWED},
  {0x1F10, 0x1F15, PVALID},
  {0x1F18, 0x1F1D, DISALLOWED},
  {0x1F20, 0x1F27, PVALID},
  {0x1F28, 0x1F2F, DISALLOWED},
  {0x1F30, 0x1F37, PVALID},
  {0x1F38, 0x1F3F, DISALLOWED},
  {0x1F40, 0x1F45, PVALID},
  {0x1F48, 0x1F4D, DISALLOWED},
  {0x1F50, 0x1F57, PVALID},
  {0x1F59, 0x1F59, DISALLOWED},
  {0x1F5B, 0x1F5B, DISALLOWED},
  {0x1F5D, 0x1F5D, DISALLOWED},
  {0x1F5F, 0x1F5F, DISALLOWED},
  {0x1F60, 0x1F67, PVALID},
  {0x1F68, 0x1F6F, DISALLOWED},
  {0x1F70, 0x1F70, PVALID},
  {0x1F71, 0x1F71, DISALLOWED},
  {0x1F72, 0x1F72, PVALID},
  {0x1F73, 0x1F73, DISALLOWED},
  {0x1F74, 0x1F74, PVALID},
  {0x1F75, 0x1F75, DISALLOWED},
  {0x1F76, 0x1F76, PVALID},
  {0x1F77, 0x1F77, DISALLOWED},
  {0x1F78, 0x1F78, PVALID},
  {0x1F79, 0x1F79, DISALLOWED},
  {0x1F7A, 0x1F7A, PVALID},
  {0x1F7B, 0x1F7B, DISALLOWED},
  {0x1F7C, 0x1F7C, PVALID},
  {0x1F7D, 0x1F7D, DISALLOWED},
  {0x1F80, 0x1FAF, DISALLOWED},
  {0x1FB0, 0x1FB1, PVALID},
  {0x1FB2, 0x1FB4, DISALLOWED},
  {0x1FB6, 0x1FB6, PVALID},
  {0x1FB7, 0x1FC4, DISALLOWED},
  {0x1FC6, 0x1FC6, PVALID},
  {0x1FC7, 0x1FCF, DISALLOWED},
  {0x1FD0, 0x1FD2, PVALID},
  {0x1FD3, 0x1FD3, DISALLOWED},
  {0x1FD6, 0x1FD7, PVALID},
  {0x1FD8, 0x1FDB, DISALLOWED},
  {0x1FDD, 0x1FDF, DISALLOWED},
  {0x1FE0, 0x1FE2, PVALID},
  {0x1FE3, 0x1FE3, DISALLOWED},
  {0x1FE4, 0x1FE7, PVALID},
  {0x1FE8, 0x1FEF, DISALLOWED},
  {0x1FF2, 0x1FF4, DISALLOWED},
  {0x1FF6, 0x1FF6, PVALID},
  {0x1FF7, 0x1FFE, DISALLOWED},
  {0x2000, 0x200B, DISALLOWED},
  {0x200C, 0x200D, CONTEXTJ},
  {0x200E, 0x2064, DISALLOWED},
  {0x2066, 0x2071, DISALLOWED},
  {0x2074, 0x208E, DISALLOWED},
  {0x2090, 0x209C, DISALLOWED},
  {0x20A0, 0x20BF, DISALLOWED},
  {0x20D0, 0x20F0, DISALLOWED},
  {0x2100, 0x214D, DISALLOWED},
  {0x214E, 0x214E, PVALID},
  {0x214F, 0x2183, DISALLOWED},
  {0x2184, 0x2184, PVALID},
  {0x2185, 0x218B, DISALLOWED},
  {0x2190, 0x2426, DISALLOWED},
  {0x2440, 0x244A, DISALLOWED},
  {0x2460, 0x2B73, DISALLOWED},
  {0x2B76, 0x2B95, DISALLOWED},
  {0x2B98, 0x2C2E, DISALLOWED},
  {0x2C30, 0x2C5E, PVALID},
  {0x2C60, 0x2C60, DISALLOWED},
  {0x2C61, 0x2C61, PVALID},
  {0x2C62, 0x2C64, DISALLOWED},
  {0x2C65, 0x2C66, PVALID},
  {0x2C67, 0x2C67, DISALLOWED},
  {0x2C68, 0x2C68, PVALID},
  {0x2C69, 0x2C69, DISALLOWED},
  {0x2C6A, 0x2C6A, PVALID},
  {0x2C6B, 0x2C6B, DISALLOWED},
  {0x2C6C, 0x2C6C, PVALID},
  {0x2C6D, 0x2C70, DISALLOWED},
  {0x2C71, 0x2C71, PVALID},
  {0x2C72, 0x2C72, DISALLOWED},
  {0x2C73, 0x2C74, PVALID},
  {0x2C75, 0x2C75, DISALLOWED},
  {0x2C76, 0x2C7B, PVALID},
  {0x2C7C, 0x2C80, DISALLOWED},
  {0x2C81, 0x2C81, PVALID},
  {0x2C82, 0x2C82, DISALLOWED},
  {0x2C83, 0x2C83, PVALID},
  {0x2C84, 0x2C84, DISALLOWED},
  {0x2C85, 0x2C85, PVALID},
  {0x2C86, 0x2C86, DISALLOWED},
  {0x2C87, 0x2C87, PVALID},
  {0x2C88, 0x2C88, DISALLOWED},
  {0x2C89, 0x2C89, PVALID},
  {0x2C8A, 0x2C8A, DISALLOWED},
  {0x2C8B, 0x2C8B, PVALID},
  {0x2C8C, 0x2C8C, DISALLOWED},
  {0x2C8D, 0x2C8D, PVALID},
  {0x2C8E, 0x2C8E, DISALLOWED},
  {0x2C8F, 0x2C8F, PVALID},
  {0x2C90, 0x2C90, DISALLOWED},
  {0x2C91, 0x2C91, PVALID},
  {0x2C92, 0x2C92, DISALLOWED},
  {0x2C93, 0x2C93, PVALID},
  {0x2C94, 0x2C94, DISALLOWED},
  {0x2C95, 0x2C95, PVALID},
  {0x2C96, 0x2C96, DISALLOWED},
  {0x2C97, 0x2C97, PVALID},
  {0x2C98, 0x2C98, DISALLOWED},
  {0x2C99, 0x2C99, PVALID},
  {0x2C9A, 0x2C9A, DISALLOWED},
  {0x2C9B, 0x2C9B, PVALID},
  {0x2C9C, 0x2C9C, DISALLOWED},
  {0x2C9D, 0x2C9D, PVALID},
  {0x2C9E, 0x2C9E, DISALLOWED},
  {0x2C9F, 0x2C9F, PVALID},
  {0x2CA0, 0x2CA0, DISALLOWED},
  {0x2CA1, 0x2CA1, PVALID},
  {0x2CA2, 0x2CA2, DISALLOWED},
  {0x2CA3, 0x2CA3, PVALID},
  {0x2CA4, 0x2CA4, DISALLOWED},
  {0x2CA5, 0x2CA5, PVALID},
  {0x2CA6, 0x2CA6, DISALLOWED},
  {0x2CA7, 0x2CA7, PVALID},
  {0x2CA8, 0x2CA8, DISALLOWED},
  {0x2CA9, 0x2CA9, PVALID},
  {0x2CAA, 0x2CAA, DISALLOWED},
  {0x2CAB, 0x2CAB, PVALID},
  {0x2CAC, 0x2CAC, DISALLOWED},
  {0x2CAD, 0x2CAD, PVALID},
  {0x2CAE, 0x2CAE, DISALLOWED},
  {0x2CAF, 0x2CAF, PVALID},
  {0x2CB0, 0x2CB0, DISALLOWED},
  {0x2CB1, 0x2CB1, PVALID},
  {0x2CB2, 0x2CB2, DISALLOWED},
  {0x2CB3, 0x2CB3, PVALID},
  {0x2CB4, 0x2CB4, DISALLOWED},
  {0x2CB5, 0x2CB5, PVALID},
  {0x2CB6, 0x2CB6, DISALLOWED},
  {0x2CB7, 0x2CB7, PVALID},
  {0x2CB8, 0x2CB8, DISALLOWED},
  {0x2CB9, 0x2CB9, PVALID},
  {0x2CBA, 0x2CBA, DISALLOWED},
  {0x2CBB, 0x2CBB, PVALID},
  {0x2CBC, 0x2CBC, DISALLOWED},
  {0x2CBD, 0x2CBD, PVALID},
  {0x2CBE, 0x2CBE, DISALLOWED},
  {0x2CBF, 0x2CBF, PVALID},
  {0x2CC0, 0x2CC0, DISALLOWED},
  {0x2CC1, 0x2CC1, PVALID},
  {0x2CC2, 0x2CC2, DISALLOWED},
  {0x2CC3, 0x2CC3, PVALID},
  {0x2CC4, 0x2CC4, DISALLOWED},
  {0x2CC5, 0x2CC5, PVALID},
  {0x2CC6, 0x2CC6, DISALLOWED},
  {0x2CC7, 0x2CC7, PVALID},
  {0x2CC8, 0x2CC8, DISALLOWED},
  {0x2CC9, 0x2CC9, PVALID},
  {0x2CCA, 0x2CCA, DISALLOWED},
  {0x2CCB, 0x2CCB, PVALID},
  {0x2CCC, 0x2CCC, DISALLOWED},
  {0x2CCD, 0x2CCD, PVALID},
  {0x2CCE, 0x2CCE, DISALLOWED},
  {0x2CCF, 0x2CCF, PVALID},
  {0x2CD0, 0x2CD0, DISALLOWED},
  {0x2CD1, 0x2CD1, PVALID},
  {0x2CD2, 0x2CD2, DISALLOWED},
  {0x2CD3, 0x2CD3, PVALID},
  {0x2CD4, 0x2CD4, DISALLOWED},
  {0x2CD5, 0x2CD5, PVALID},
  {0x2CD6, 0x2CD6, DISALLOWED},
  {0x2CD7, 0x2CD7, PVALID},
  {0x2CD8, 0x2CD8, DISALLOWED},
  {0x2CD9, 0x2CD9, PVALID},
  {0x2CDA, 0x2CDA, DISALLOWED},
  {0x2CDB, 0x2CDB, PVALID},
  {0x2CDC, 0x2CDC, DISALLOWED},
  {0x2CDD, 0x2CDD, PVALID},
  {0x2CDE, 0x2CDE, DISALLOWED},
  {0x2CDF, 0x2CDF, PVALID},
  {0x2CE0, 0x2CE0, DISALLOWED},
  {0x2CE1, 0x2CE1, PVALID},
  {0x2CE2, 0x2CE2, DISALLOWED},
  {0x2CE3, 0x2CE4, PVALID},
  {0x2CE5, 0x2CEB, DISALLOWED},
  {0x2CEC, 0x2CEC, PVALID},
  {0x2CED, 0x2CED, DISALLOWED},
  {0x2CEE, 0x2CF1, PVALID},
  {0x2CF2, 0x2CF2, DISALLOWED},
  {0x2CF3, 0x2CF3, PVALID},
  {0x2CF9, 0x2CFF, DISALLOWED},
  {0x2D00, 0x2D25, PVALID},
  {0x2D27, 0x2D27, PVALID},
  {0x2D2D, 0x2D2D, PVALID},
  {0x2D30, 0x2D67, PVALID},
  {0x2D6F, 0x2D70, DISALLOWED},
  {0x2D7F, 0x2D96, PVALID},
  {0x2DA0, 0x2DA6, PVALID},
  {0x2DA8, 0x2DAE, PVALID},
  {0x2DB0, 0x2DB6, PVALID},
  {0x2DB8, 0x2DBE, PVALID},
  {0x2DC0, 0x2DC6, PVALID},
  {0x2DC8, 0x2DCE, PVALID},
  {0x2DD0, 0x2DD6, PVALID},
  {0x2DD8, 0x2DDE, PVALID},
  {0x2DE0, 0x2DFF, PVALID},
  {0x2E00, 0x2E2E, DISALLOWED},
  {0x2E2F, 0x2E2F, PVALID},
  {0x2E30, 0x2E4F, DISALLOWED},
  {0x2E80, 0x2E99, DISALLOWED},
  {0x2E9B, 0x2EF3, DISALLOWED},
  {0x2F00, 0x2FD5, DISALLOWED},
  {0x2FF0, 0x2FFB, DISALLOWED},
  {0x3000, 0x3004, DISALLOWED},
  {0x3005, 0x3007, PVALID},
  {0x3008, 0x3029, DISALLOWED},
  {0x302A, 0x302D, PVALID},
  {0x302E, 0x303B, DISALLOWED},
  {0x303C, 0x303C, PVALID},
  {0x303D, 0x303F, DISALLOWED},
  {0x3041, 0x3096, PVALID},
  {0x3099, 0x309A, PVALID},
  {0x309B, 0x309C, DISALLOWED},
  {0x309D, 0x309E, PVALID},
  {0x309F, 0x30A0, DISALLOWED},
  {0x30A1, 0x30FA, PVALID},
  {0x30FB, 0x30FB, CONTEXTO},
  {0x30FC, 0x30FE, PVALID},
  {0x30FF, 0x30FF, DISALLOWED},
  {0x3105, 0x312F, PVALID},
  {0x3131, 0x318E, DISALLOWED},
  {0x3190, 0x319F, DISALLOWED},
  {0x31A0, 0x31BA, PVALID},
  {0x31C0, 0x31E3, DISALLOWED},
  {0x31F0, 0x31FF, PVALID},
  {0x3200, 0x321E, DISALLOWED},
  {0x3220, 0x32FE, DISALLOWED},
  {0x3300, 0x33FF, DISALLOWED},
  {0x3400, 0x4DB5, PVALID},
  {0x4DC0, 0x4DFF, DISALLOWED},
  {0x4E00, 0x9FEF, PVALID},
  {0xA000, 0xA48C, PVALID},
  {0xA490, 0xA4C6, DISALLOWED},
  {0xA4D0, 0xA4FD, PVALID},
  {0xA4FE, 0xA4FF, DISALLOWED},
  {0xA500, 0xA60C, PVALID},
  {0xA60D, 0xA60F, DISALLOWED},
  {0xA610, 0xA62B, PVALID},
  {0xA640, 0xA640, DISALLOWED},
  {0xA641, 0xA641, PVALID},
  {0xA642, 0xA642, DISALLOWED},
  {0xA643, 0xA643, PVALID},
  {0xA644, 0xA644, DISALLOWED},
  {0xA645, 0xA645, PVALID},
  {0xA646, 0xA646, DISALLOWED},
  {0xA647, 0xA647, PVALID},
  {0xA648, 0xA648, DISALLOWED},
  {0xA649, 0xA649, PVALID},
  {0xA64A, 0xA64A, DISALLOWED},
  {0xA64B, 0xA64B, PVALID},
  {0xA64C, 0xA64C, DISALLOWED},
  {0xA64D, 0xA64D, PVALID},
  {0xA64E, 0xA64E, DISALLOWED},
  {0xA64F, 0xA64F, PVALID},
  {0xA650, 0xA650, DISALLOWED},
  {0xA651, 0xA651, PVALID},
  {0xA652, 0xA652, DISALLOWED},
  {0xA653, 0xA653, PVALID},
  {0xA654, 0xA654, DISALLOWED},
  {0xA655, 0xA655, PVALID},
  {0xA656, 0xA656, DISALLOWED},
  {0xA657, 0xA657, PVALID},
  {0xA658, 0xA658, DISALLOWED},
  {0xA659, 0xA659, PVALID},
  {0xA65A, 0xA65A, DISALLOWED},
  {0xA65B, 0xA65B, PVALID},
  {0xA65C, 0xA65C, DISALLOWED},
  {0xA65D, 0xA65D, PVALID},
  {0xA65E, 0xA65E, DISALLOWED},
  {0xA65F, 0xA65F, PVALID},
  {0xA660, 0xA660, DISALLOWED},
  {0xA661, 0xA661, PVALID},
  {0xA662, 0xA662, DISALLOWED},
  {0xA663, 0xA663, PVALID},
  {0xA664, 0xA664, DISALLOWED},
  {0xA665, 0xA665, PVALID},
  {0xA666, 0xA666, DISALLOWED},
  {0xA667, 0xA667, PVALID},
  {0xA668, 0xA668, DISALLOWED},
  {0xA669, 0xA669, PVALID},
  {0xA66A, 0xA66A, DISALLOWED},
  {0xA66B, 0xA66B, PVALID},
  {0xA66C, 0xA66C, DISALLOWED},
  {0xA66D, 0xA66F, PVALID},
  {0xA670, 0xA673, DISALLOWED},
  {0xA674, 0xA67D, PVALID},
  {0xA67E, 0xA67E, DISALLOWED},
  {0xA67F, 0xA67F, PVALID},
  {0xA680, 0xA680, DISALLOWED},
  {0xA681, 0xA681, PVALID},
  {0xA682, 0xA682, DISALLOWED},
  {0xA683, 0xA683, PVALID},
  {0xA684, 0xA684, DISALLOWED},
  {0xA685, 0xA685, PVALID},
  {0xA686, 0xA686, DISALLOWED},
  {0xA687, 0xA687, PVALID},
  {0xA688, 0xA688, DISALLOWED},
  {0xA689, 0xA689, PVALID},
  {0xA68A, 0xA68A, DISALLOWED},
  {0xA68B, 0xA68B, PVALID},
  {0xA68C, 0xA68C, DISALLOWED},
  {0xA68D, 0xA68D, PVALID},
  {0xA68E, 0xA68E, DISALLOWED},
  {0xA68F, 0xA68F, PVALID},
  {0xA690, 0xA690, DISALLOWED},
  {0xA691, 0xA691, PVALID},
  {0xA692, 0xA692, DISALLOWED},
  {0xA693, 0xA693, PVALID},
  {0xA694, 0xA694, DISALLOWED},
  {0xA695, 0xA695, PVALID},
  {0xA696, 0xA696, DISALLOWED},
  {0xA697, 0xA697, PVALID},
  {0xA698, 0xA698, DISALLOWED},
  {0xA699, 0xA699, PVALID},
  {0xA69A, 0xA69A, DISALLOWED},
  {0xA69B, 0xA69B, PVALID},
  {0xA69C, 0xA69D, DISALLOWED},
  {0xA69E, 0xA6E5, PVALID},
  {0xA6E6, 0xA6EF, DISALLOWED},
  {0xA6F0, 0xA6F1, PVALID},
  {0xA6F2, 0xA6F7, DISALLOWED},
  {0xA700, 0xA716, DISALLOWED},
  {0xA717, 0xA71F, PVALID},
  {0xA720, 0xA722, DISALLOWED},
  {0xA723, 0xA723, PVALID},
  {0xA724, 0xA724, DISALLOWED},
  {0xA725, 0xA725, PVALID},
  {0xA726, 0xA726, DISALLOWED},
  {0xA727, 0xA727, PVALID},
  {0xA728, 0xA728, DISALLOWED},
  {0xA729, 0xA729, PVALID},
  {0xA72A, 0xA72A, DISALLOWED},
  {0xA72B, 0xA72B, PVALID},
  {0xA72C, 0xA72C, DISALLOWED},
  {0xA72D, 0xA72D, PVALID},
  {0xA72E, 0xA72E, DISALLOWED},
  {0xA72F, 0xA731, PVALID},
  {0xA732, 0xA732, DISALLOWED},
  {0xA733, 0xA733, PVALID},
  {0xA734, 0xA734, DISALLOWED},
  {0xA735, 0xA735, PVALID},
  {0xA736, 0xA736, DISALLOWED},
  {0xA737, 0xA737, PVALID},
  {0xA738, 0xA738, DISALLOWED},
  {0xA739, 0xA739, PVALID},
  {0xA73A, 0xA73A, DISALLOWED},
  {0xA73B, 0xA73B, PVALID},
  {0xA73C, 0xA73C, DISALLOWED},
  {0xA73D, 0xA73D, PVALID},
  {0xA73E, 0xA73E, DISALLOWED},
  {0xA73F, 0xA73F, PVALID},
  {0xA740, 0xA740, DISALLOWED},
  {0xA741, 0xA741, PVALID},
  {0xA742, 0xA742, DISALLOWED},
  {0xA743, 0xA743, PVALID},
  {0xA744, 0xA744, DISALLOWED},
  {0xA745, 0xA745, PVALID},
  {0xA746, 0xA746, DISALLOWED},
  {0xA747, 0xA747, PVALID},
  {0xA748, 0xA748, DISALLOWED},
  {0xA749, 0xA749, PVALID},
  {0xA74A, 0xA74A, DISALLOWED},
  {0xA74B, 0xA74B, PVALID},
  {0xA74C, 0xA74C, DISALLOWED},
  {0xA74D, 0xA74D, PVALID},
  {0xA74E, 0xA74E, DISALLOWED},
  {0xA74F, 0xA74F, PVALID},
  {0xA750, 0xA750, DISALLOWED},
  {0xA751, 0xA751, PVALID},
  {0xA752, 0xA752, DISALLOWED},
  {0xA753, 0xA753, PVALID},
  {0xA754, 0xA754, DISALLOWED},
  {0xA755, 0xA755, PVALID},
  {0xA756, 0xA756, DISALLOWED},
  {0xA757, 0xA757, PVALID},
  {0xA758, 0xA758, DISALLOWED},
  {0xA759, 0xA759, PVALID},
  {0xA75A, 0xA75A, DISALLOWED},
  {0xA75B, 0xA75B, PVALID},
  {0xA75C, 0xA75C, DISALLOWED},
  {0xA75D, 0xA75D, PVALID},
  {0xA75E, 0xA75E, DISALLOWED},
  {0xA75F, 0xA75F, PVALID},
  {0xA760, 0xA760, DISALLOWED},
  {0xA761, 0xA761, PVALID},
  {0xA762, 0xA762, DISALLOWED},
  {0xA763, 0xA763, PVALID},
  {0xA764, 0xA764, DISALLOWED},
  {0xA765, 0xA765, PVALID},
  {0xA766, 0xA766, DISALLOWED},
  {0xA767, 0xA767, PVALID},
  {0xA768, 0xA768, DISALLOWED},
  {0xA769, 0xA769, PVALID},
  {0xA76A, 0xA76A, DISALLOWED},
  {0xA76B, 0xA76B, PVALID},
  {0xA76C, 0xA76C, DISALLOWED},
  {0xA76D, 0xA76D, PVALID},
  {0xA76E, 0xA76E, DISALLOWED},
  {0xA76F, 0xA76F, PVALID},
  {0xA770, 0xA770, DISALLOWED},
  {0xA771, 0xA778, PVALID},
  {0xA779, 0xA779, DISALLOWED},
  {0xA77A, 0xA77A, PVALID},
  {0xA77B, 0xA77B, DISALLOWED},
  {0xA77C, 0xA77C, PVALID},
  {0xA77D, 0xA77E, DISALLOWED},
  {0xA77F, 0xA77F, PVALID},
  {0xA780, 0xA780, DISALLOWED},
  {0xA781, 0xA781, PVALID},
  {0xA782, 0xA782, DISALLOWED},
  {0xA783, 0xA783, PVALID},
  {0xA784, 0xA784, DISALLOWED},
  {0xA785, 0xA785, PVALID},
  {0xA786, 0xA786, DISALLOWED},
  {0xA787, 0xA788, PVALID},
  {0xA789, 0xA78B, DISALLOWED},
  {0xA78C, 0xA78C, PVALID},
  {0xA78D, 0xA78D, DISALLOWED},
  {0xA78E, 0xA78F, PVALID},
  {0xA790, 0xA790, DISALLOWED},
  {0xA791, 0xA791, PVALID},
  {0xA792, 0xA792, DISALLOWED},
  {0xA793, 0xA795, PVALID},
  {0xA796, 0xA796, DISALLOWED},
  {0xA797, 0xA797, PVALID},
  {0xA798, 0xA798, DISALLOWED},
  {0xA799, 0xA799, PVALID},
  {0xA79A, 0xA79A, DISALLOWED},
  {0xA79B, 0xA79B, PVALID},
  {0xA79C, 0xA79C, DISALLOWED},
  {0xA79D, 0xA79D, PVALID},
  {0xA79E, 0xA79E, DISALLOWED},
  {0xA79F, 0xA79F, PVALID},
  {0xA7A0, 0xA7A0, DISALLOWED},
  {0xA7A1, 0xA7A1, PVALID},
  {0xA7A2, 0xA7A2, DISALLOWED},
  {0xA7A3, 0xA7A3, PVALID},
  {0xA7A4, 0xA7A4, DISALLOWED},
  {0xA7A5, 0xA7A5, PVALID},
  {0xA7A6, 0xA7A6, DISALLOWED},
  {0xA7A7, 0xA7A7, PVALID},
  {0xA7A8, 0xA7A8, DISALLOWED},
  {0xA7A9, 0xA7A9, PVALID},
  {0xA7AA, 0xA7AE, DISALLOWED},
  {0xA7AF, 0xA7AF, PVALID},
  {0xA7B0, 0xA7B4, DISALLOWED},
  {0xA7B5, 0xA7B5, PVALID},
  {0xA7B6, 0xA7B6, DISALLOWED},
  {0xA7B7, 0xA7B7, PVALID},
  {0xA7B8, 0xA7B8, DISALLOWED},
  {0xA7B9, 0xA7B9, PVALID},
  {0xA7BA, 0xA7BA, DISALLOWED},
  {0xA7BB, 0xA7BB, PVALID},
  {0xA7BC, 0xA7BC, DISALLOWED},
  {0xA7BD, 0xA7BD, PVALID},
  {0xA7BE, 0xA7BE, DISALLOWED},
  {0xA7BF, 0xA7BF, PVALID},
  {0xA7C2, 0xA7C2, DISALLOWED},
  {0xA7C3, 0xA7C3, PVALID},
  {0xA7C4, 0xA7C6, DISALLOWED},
  {0xA7F7, 0xA7F7, PVALID},
  {0xA7F8, 0xA7F9, DISALLOWED},
  {0xA7FA, 0xA827, PVALID},
  {0xA828, 0xA82B, DISALLOWED},
  {0xA830, 0xA839, DISALLOWED},
  {0xA840, 0xA873, PVALID},
  {0xA874, 0xA877, DISALLOWED},
  {0xA880, 0xA8C5, PVALID},
  {0xA8CE, 0xA8CF, DISALLOWED},
  {0xA8D0, 0xA8D9, PVALID},
  {0xA8E0, 0xA8F7, PVALID},
  {0xA8F8, 0xA8FA, DISALLOWED},
  {0xA8FB, 0xA8FB, PVALID},
  {0xA8FC, 0xA8FC, DISALLOWED},
  {0xA8FD, 0xA92D, PVALID},
  {0xA92E, 0xA92F, DISALLOWED},
  {0xA930, 0xA953, PVALID},
  {0xA95F, 0xA97C, DISALLOWED},
  {0xA980, 0xA9C0, PVALID},
  {0xA9C1, 0xA9CD, DISALLOWED},
  {0xA9CF, 0xA9D9, PVALID},
  {0xA9DE, 0xA9DF, DISALLOWED},
  {0xA9E0, 0xA9FE, PVALID},
  {0xAA00, 0xAA36, PVALID},
  {0xAA40, 0xAA4D, PVALID},
  {0xAA50, 0xAA59, PVALID},
  {0xAA5C, 0xAA5F, DISALLOWED},
  {0xAA60, 0xAA76, PVALID},
  {0xAA77, 0xAA79, DISALLOWED},
  {0xAA7A, 0xAAC2, PVALID},
  {0xAADB, 0xAADD, PVALID},
  {0xAADE, 0xAADF, DISALLOWED},
  {0xAAE0, 0xAAEF, PVALID},
  {0xAAF0, 0xAAF1, DISALLOWED},
  {0xAAF2, 0xAAF6, PVALID},
  {0xAB01, 0xAB06, PVALID},
  {0xAB09, 0xAB0E, PVALID},
  {0xAB11, 0xAB16, PVALID},
  {0xAB20, 0xAB26, PVALID},
  {0xAB28, 0xAB2E, PVALID},
  {0xAB30, 0xAB5A, PVALID},
  {0xAB5B, 0xAB5F, DISALLOWED},
  {0xAB60, 0xAB67, PVALID},
  {0xAB70, 0xABBF, DISALLOWED},
  {0xABC0, 0xABEA, PVALID},
  {0xABEB, 0xABEB, DISALLOWED},
  {0xABEC, 0xABED, PVALID},
  {0xABF0, 0xABF9, PVALID},
  {0xAC00, 0xD7A3, PVALID},
  {0xD7B0, 0xD7C6, DISALLOWED},
  {0xD7CB, 0xD7FB, DISALLOWED},
  {0xD800, 0xFA0D, DISALLOWED},
  {0xFA0E, 0xFA0F, PVALID},
  {0xFA10, 0xFA10, DISALLOWED},
  {0xFA11, 0xFA11, PVALID},
  {0xFA12, 0xFA12, DISALLOWED},
  {0xFA13, 0xFA14, PVALID},
  {0xFA15, 0xFA1E, DISALLOWED},
  {0xFA1F, 0xFA1F, PVALID},
  {0xFA20, 0xFA20, DISALLOWED},
  {0xFA21, 0xFA21, PVALID},
  {0xFA22, 0xFA22, DISALLOWED},
  {0xFA23, 0xFA24, PVALID},
  {0xFA25, 0xFA26, DISALLOWED},
  {0xFA27, 0xFA29, PVALID},
  {0xFA2A, 0xFA6D, DISALLOWED},
  {0xFA70, 0xFAD9, DISALLOWED},
  {0xFB00, 0xFB06, DISALLOWED},
  {0xFB13, 0xFB17, DISALLOWED},
  {0xFB1D, 0xFB1D, DISALLOWED},
  {0xFB1E, 0xFB1E, PVALID},
  {0xFB1F, 0xFB36, DISALLOWED},
  {0xFB38, 0xFB3C, DISALLOWED},
  {0xFB3E, 0xFB3E, DISALLOWED},
  {0xFB40, 0xFB41, DISALLOWED},
  {0xFB43, 0xFB44, DISALLOWED},
  {0xFB46, 0xFBC1, DISALLOWED},
  {0xFBD3, 0xFD3F, DISALLOWED},
  {0xFD50, 0xFD8F, DISALLOWED},
  {0xFD92, 0xFDC7, DISALLOWED},
  {0xFDD0, 0xFDFD, DISALLOWED},
  {0xFE00, 0xFE19, DISALLOWED},
  {0xFE20, 0xFE2F, PVALID},
  {0xFE30, 0xFE52, DISALLOWED},
  {0xFE54, 0xFE66, DISALLOWED},
  {0xFE68, 0xFE6B, DISALLOWED},
  {0xFE70, 0xFE72, DISALLOWED},
  {0xFE73, 0xFE73, PVALID},
  {0xFE74, 0xFE74, DISALLOWED},
  {0xFE76, 0xFEFC, DISALLOWED},
  {0xFEFF, 0xFEFF, DISALLOWED},
  {0xFF01, 0xFFBE, DISALLOWED},
  {0xFFC2, 0xFFC7, DISALLOWED},
  {0xFFCA, 0xFFCF, DISALLOWED},
  {0xFFD2, 0xFFD7, DISALLOWED},
  {0xFFDA, 0xFFDC, DISALLOWED},
  {0xFFE0, 0xFFE6, DISALLOWED},
  {0xFFE8, 0xFFEE, DISALLOWED},
  {0xFFF9, 0xFFFF, DISALLOWED},
  {0x10000, 0x1000B, PVALID},
  {0x1000D, 0x10026, PVALID},
  {0x10028, 0x1003A, PVALID},
  {0x1003C, 0x1003D, PVALID},
  {0x1003F, 0x1004D, PVALID},
  {0x10050, 0x1005D, PVALID},
  {0x10080, 0x100FA, PVALID},
  {0x10100, 0x10102, DISALLOWED},
  {0x10107, 0x10133, DISALLOWED},
  {0x10137, 0x1018E, DISALLOWED},
  {0x10190, 0x1019B, DISALLOWED},
  {0x101A0, 0x101A0, DISALLOWED},
  {0x101D0, 0x101FC, DISALLOWED},
  {0x101FD, 0x101FD, PVALID},
  {0x10280, 0x1029C, PVALID},
  {0x102A0, 0x102D0, PVALID},
  {0x102E0, 0x102E0, PVALID},
  {0x102E1, 0x102FB, DISALLOWED},
  {0x10300, 0x1031F, PVALID},
  {0x10320, 0x10323, DISALLOWED},
  {0x1032D, 0x10340, PVALID},
  {0x10341, 0x10341, DISALLOWED},
  {0x10342, 0x10349, PVALID},
  {0x1034A, 0x1034A, DISALLOWED},
  {0x10350, 0x1037A, PVALID},
  {0x10380, 0x1039D, PVALID},
  {0x1039F, 0x1039F, DISALLOWED},
  {0x103A0, 0x103C3, PVALID},
  {0x103C8, 0x103CF, PVALID},
  {0x103D0, 0x103D5, DISALLOWED},
  {0x10400, 0x10427, DISALLOWED},
  {0x10428, 0x1049D, PVALID},
  {0x104A0, 0x104A9, PVALID},
  {0x104B0, 0x104D3, DISALLOWED},
  {0x104D8, 0x104FB, PVALID},
  {0x10500, 0x10527, PVALID},
  {0x10530, 0x10563, PVALID},
  {0x1056F, 0x1056F, DISALLOWED},
  {0x10600, 0x10736, PVALID},
  {0x10740, 0x10755, PVALID},
  {0x10760, 0x10767, PVALID},
  {0x10800, 0x10805, PVALID},
  {0x10808, 0x10808, PVALID},
  {0x1080A, 0x10835, PVALID},
  {0x10837, 0x10838, PVALID},
  {0x1083C, 0x1083C, PVALID},
  {0x1083F, 0x10855, PVALID},
  {0x10857, 0x1085F, DISALLOWED},
  {0x10860, 0x10876, PVALID},
  {0x10877, 0x1087F, DISALLOWED},
  {0x10880, 0x1089E, PVALID},
  {0x108A7, 0x108AF, DISALLOWED},
  {0x108E0, 0x108F2, PVALID},
  {0x108F4, 0x108F5, PVALID},
  {0x108FB, 0x108FF, DISALLOWED},
  {0x10900, 0x10915, PVALID},
  {0x10916, 0x1091B, DISALLOWED},
  {0x1091F, 0x1091F, DISALLOWED},
  {0x10920, 0x10939, PVALID},
  {0x1093F, 0x1093F, DISALLOWED},
  {0x10980, 0x109B7, PVALID},
  {0x109BC, 0x109BD, DISALLOWED},
  {0x109BE, 0x109BF, PVALID},
  {0x109C0, 0x109CF, DISALLOWED},
  {0x109D2, 0x109FF, DISALLOWED},
  {0x10A00, 0x10A03, PVALID},
  {0x10A05, 0x10A06, PVALID},
  {0x10A0C, 0x10A13, PVALID},
  {0x10A15, 0x10A17, PVALID},
  {0x10A19, 0x10A35, PVALID},
  {0x10A38, 0x10A3A, PVALID},
  {0x10A3F, 0x10A3F, PVALID},
  {0x10A40, 0x10A48, DISALLOWED},
  {0x10A50, 0x10A58, DISALLOWED},
  {0x10A60, 0x10A7C, PVALID},
  {0x10A7D, 0x10A7F, DISALLOWED},
  {0x10A80, 0x10A9C, PVALID},
  {0x10A9D, 0x10A9F, DISALLOWED},
  {0x10AC0, 0x10AC7, PVALID},
  {0x10AC8, 0x10AC8, DISALLOWED},
  {0x10AC9, 0x10AE6, PVALID},
  {0x10AEB, 0x10AF6, DISALLOWED},
  {0x10B00, 0x10B35, PVALID},
  {0x10B39, 0x10B3F, DISALLOWED},
  {0x10B40, 0x10B55, PVALID},
  {0x10B58, 0x10B5F, DISALLOWED},
  {0x10B60, 0x10B72, PVALID},
  {0x10B78, 0x10B7F, DISALLOWED},
  {0x10B80, 0x10B91, PVALID},
  {0x10B99, 0x10B9C, DISALLOWED},
  {0x10BA9, 0x10BAF, DISALLOWED},
  {0x10C00, 0x10C48, PVALID},
  {0x10C80, 0x10CB2, DISALLOWED},
  {0x10CC0, 0x10CF2, PVALID},
  {0x10CFA, 0x10CFF, DISALLOWED},
  {0x10D00, 0x10D27, PVALID},
  {0x10D30, 0x10D39, PVALID},
  {0x10E60, 0x10E7E, DISALLOWED},
  {0x10F00, 0x10F1C, PVALID},
  {0x10F1D, 0x10F26, DISALLOWED},
  {0x10F27, 0x10F27, PVALID},
  {0x10F30, 0x10F50, PVALID},
  {0x10F51, 0x10F59, DISALLOWED},
  {0x10FE0, 0x10FF6, PVALID},
  {0x11000, 0x11046, PVALID},
  {0x11047, 0x1104D, DISALLOWED},
  {0x11052, 0x11065, DISALLOWED},
  {0x11066, 0x1106F, PVALID},
  {0x1107F, 0x110BA, PVALID},
  {0x110BB, 0x110C1, DISALLOWED},
  {0x110CD, 0x110CD, DISALLOWED},
  {0x110D0, 0x110E8, PVALID},
  {0x110F0, 0x110F9, PVALID},
  {0x11100, 0x11134, PVALID},
  {0x11136, 0x1113F, PVALID},
  {0x11140, 0x11143, DISALLOWED},
  {0x11144, 0x11146, PVALID},
  {0x11150, 0x11173, PVALID},
  {0x11174, 0x11175, DISALLOWED},
  {0x11176, 0x11176, PVALID},
  {0x11180, 0x111C4, PVALID},
  {0x111C5, 0x111C8, DISALLOWED},
  {0x111C9, 0x111CC, PVALID},
  {0x111CD, 0x111CD, DISALLOWED},
  {0x111D0, 0x111DA, PVALID},
  {0x111DB, 0x111DB, DISALLOWED},
  {0x111DC, 0x111DC, PVALID},
  {0x111DD, 0x111DF, DISALLOWED},
  {0x111E1, 0x111F4, DISALLOWED},
  {0x11200, 0x11211, PVALID},
  {0x11213, 0x11237, PVALID},
  {0x11238, 0x1123D, DISALLOWED},
  {0x1123E, 0x1123E, PVALID},
  {0x11280, 0x11286, PVALID},
  {0x11288, 0x11288, PVALID},
  {0x1128A, 0x1128D, PVALID},
  {0x1128F, 0x1129D, PVALID},
  {0x1129F, 0x112A8, PVALID},
  {0x112A9, 0x112A9, DISALLOWED},
  {0x112B0, 0x112EA, PVALID},
  {0x112F0, 0x112F9, PVALID},
  {0x11300, 0x11303, PVALID},
  {0x11305, 0x1130C, PVALID},
  {0x1130F, 0x11310, PVALID},
  {0x11313, 0x11328, PVALID},
  {0x1132A, 0x11330, PVALID},
  {0x11332, 0x11333, PVALID},
  {0x11335, 0x11339, PVALID},
  {0x1133B, 0x11344, PVALID},
  {0x11347, 0x11348, PVALID},
  {0x1134B, 0x1134D, PVALID},
  {0x11350, 0x11350, PVALID},
  {0x11357, 0x11357, PVALID},
  {0x1135D, 0x11363, PVALID},
  {0x11366, 0x1136C, PVALID},
  {0x11370, 0x11374, PVALID},
  {0x11400, 0x1144A, PVALID},
  {0x1144B, 0x1144F, DISALLOWED},
  {0x11450, 0x11459, PVALID},
  {0x1145B, 0x1145B, DISALLOWED},
  {0x1145D, 0x1145D, DISALLOWED},
  {0x1145E, 0x1145F, PVALID},
  {0x11480, 0x114C5, PVALID},
  {0x114C6, 0x114C6, DISALLOWED},
  {0x114C7, 0x114C7, PVALID},
  {0x114D0, 0x114D9, PVALID},
  {0x11580, 0x115B5, PVALID},
  {0x115B8, 0x115C0, PVALID},
  {0x115C1, 0x115D7, DISALLOWED},
  {0x115D8, 0x115DD, PVALID},
  {0x11600, 0x11640, PVALID},
  {0x11641, 0x11643, DISALLOWED},
  {0x11644, 0x11644, PVALID},
  {0x11650, 0x11659, PVALID},
  {0x11660, 0x1166C, DISALLOWED},
  {0x11680, 0x116B8, PVALID},
  {0x116C0, 0x116C9, PVALID},
  {0x11700, 0x1171A, PVALID},
  {0x1171D, 0x1172B, PVALID},
  {0x11730, 0x11739, PVALID},
  {0x1173A, 0x1173F, DISALLOWED},
  {0x11800, 0x1183A, PVALID},
  {0x1183B, 0x1183B, DISALLOWED},
  {0x118A0, 0x118BF, DISALLOWED},
  {0x118C0, 0x118E9, PVALID},
  {0x118EA, 0x118F2, DISALLOWED},
  {0x118FF, 0x118FF, PVALID},
  {0x119A0, 0x119A7, PVALID},
  {0x119AA, 0x119D7, PVALID},
  {0x119DA, 0x119E1, PVALID},
  {0x119E2, 0x119E2, DISALLOWED},
  {0x119E3, 0x119E4, PVALID},
  {0x11A00, 0x11A3E, PVALID},
  {0x11A3F, 0x11A46, DISALLOWED},
  {0x11A47, 0x11A47, PVALID},
  {0x11A50, 0x11A99, PVALID},
  {0x11A9A, 0x11A9C, DISALLOWED},
  {0x11A9D, 0x11A9D, PVALID},
  {0x11A9E, 0x11AA2, DISALLOWED},
  {0x11AC0, 0x11AF8, PVALID},
  {0x11C00, 0x11C08, PVALID},
  {0x11C0A, 0x11C36, PVALID},
  {0x11C38, 0x11C40, PVALID},
  {0x11C41, 0x11C45, DISALLOWED},
  {0x11C50, 0x11C59, PVALID},
  {0x11C5A, 0x11C6C, DISALLOWED},
  {0x11C70, 0x11C71, DISALLOWED},
  {0x11C72, 0x11C8F, PVALID},
  {0x11C92, 0x11CA7, PVALID},
  {0x11CA9, 0x11CB6, PVALID},
  {0x11D00, 0x11D06, PVALID},
  {0x11D08, 0x11D09, PVALID},
  {0x11D0B, 0x11D36, PVALID},
  {0x11D3A, 0x11D3A, PVALID},
  {0x11D3C, 0x11D3D, PVALID},
  {0x11D3F, 0x11D47, PVALID},
  {0x11D50, 0x11D59, PVALID},
  {0x11D60, 0x11D65, PVALID},
  {0x11D67, 0x11D68, PVALID},
  {0x11D6A, 0x11D8E, PVALID},
  {0x11D90, 0x11D91, PVALID},
  {0x11D93, 0x11D98, PVALID},
  {0x11DA0, 0x11DA9, PVALID},
  {0x11EE0, 0x11EF6, PVALID},
  {0x11EF7, 0x11EF8, DISALLOWED},
  {0x11FC0, 0x11FF1, DISALLOWED},
  {0x11FFF, 0x11FFF, DISALLOWED},
  {0x12000, 0x12399, PVALID},
  {0x12400, 0x1246E, DISALLOWED},
  {0x12470, 0x12474, DISALLOWED},
  {0x12480, 0x12543, PVALID},
  {0x13000, 0x1342E, PVALID},
  {0x13430, 0x13438, DISALLOWED},
  {0x14400, 0x14646, PVALID},
  {0x16800, 0x16A38, PVALID},
  {0x16A40, 0x16A5E, PVALID},
  {0x16A60, 0x16A69, PVALID},
  {0x16A6E, 0x16A6F, DISALLOWED},
  {0x16AD0, 0x16AED, PVALID},
  {0x16AF0, 0x16AF4, PVALID},
  {0x16AF5, 0x16AF5, DISALLOWED},
  {0x16B00, 0x16B36, PVALID},
  {0x16B37, 0x16B3F, DISALLOWED},
  {0x16B40, 0x16B43, PVALID},
  {0x16B44, 0x16B45, DISALLOWED},
  {0x16B50, 0x16B59, PVALID},
  {0x16B5B, 0x16B61, DISALLOWED},
  {0x16B63, 0x16B77, PVALID},
  {0x16B7D, 0x16B8F, PVALID},
  {0x16E40, 0x16E5F, DISALLOWED},
  {0x16E60, 0x16E7F, PVALID},
  {0x16E80, 0x16E9A, DISALLOWED},
  {0x16F00, 0x16F4A, PVALID},
  {0x16F4F, 0x16F87, PVALID},
  {0x16F8F, 0x16F9F, PVALID},
  {0x16FE0, 0x16FE1, PVALID},
  {0x16FE2, 0x16FE2, DISALLOWED},
  {0x16FE3, 0x16FE3, PVALID},
  {0x17000, 0x187F7, PVALID},
  {0x18800, 0x18AF2, PVALID},
  {0x1B000, 0x1B11E, PVALID},
  {0x1B150, 0x1B152, PVALID},
  {0x1B164, 0x1B167, PVALID},
  {0x1B170, 0x1B2FB, PVALID},
  {0x1BC00, 0x1BC6A, PVALID},
  {0x1BC70, 0x1BC7C, PVALID},
  {0x1BC80, 0x1BC88, PVALID},
  {0x1BC90, 0x1BC99, PVALID},
  {0x1BC9C, 0x1BC9C, DISALLOWED},
  {0x1BC9D, 0x1BC9E, PVALID},
  {0x1BC9F, 0x1BCA3, DISALLOWED},
  {0x1D000, 0x1D0F5, DISALLOWED},
  {0x1D100, 0x1D126, DISALLOWED},
  {0x1D129, 0x1D1E8, DISALLOWED},
  {0x1D200, 0x1D245, DISALLOWED},
  {0x1D2E0, 0x1D2F3, DISALLOWED},
  {0x1D300, 0x1D356, DISALLOWED},
  {0x1D360, 0x1D378, DISALLOWED},
  {0x1D400, 0x1D454, DISALLOWED},
  {0x1D456, 0x1D49C, DISALLOWED},
  {0x1D49E, 0x1D49F, DISALLOWED},
  {0x1D4A2, 0x1D4A2, DISALLOWED},
  {0x1D4A5, 0x1D4A6, DISALLOWED},
  {0x1D4A9, 0x1D4AC, DISALLOWED},
  {0x1D4AE, 0x1D4B9, DISALLOWED},
  {0x1D4BB, 0x1D4BB, DISALLOWED},
  {0x1D4BD, 0x1D4C3, DISALLOWED},
  {0x1D4C5, 0x1D505, DISALLOWED},
  {0x1D507, 0x1D50A, DISALLOWED},
  {0x1D50D, 0x1D514, DISALLOWED},
  {0x1D516, 0x1D51C, DISALLOWED},
  {0x1D51E, 0x1D539, DISALLOWED},
  {0x1D53B, 0x1D53E, DISALLOWED},
  {0x1D540, 0x1D544, DISALLOWED},
  {0x1D546, 0x1D546, DISALLOWED},
  {0x1D54A, 0x1D550, DISALLOWED},
  {0x1D552, 0x1D6A5, DISALLOWED},
  {0x1D6A8, 0x1D7CB, DISALLOWED},
  {0x1D7CE, 0x1D9FF, DISALLOWED},
  {0x1DA00, 0x1DA36, PVALID},
  {0x1DA37, 0x1DA3A, DISALLOWED},
  {0x1DA3B, 0x1DA6C, PVALID},
  {0x1DA6D, 0x1DA74, DISALLOWED},
  {0x1DA75, 0x1DA75, PVALID},
  {0x1DA76, 0x1DA83, DISALLOWED},
  {0x1DA84, 0x1DA84, PVALID},
  {0x1DA85, 0x1DA8B, DISALLOWED},
  {0x1DA9B, 0x1DA9F, PVALID},
  {0x1DAA1, 0x1DAAF, PVALID},
  {0x1E000, 0x1E006, PVALID},
  {0x1E008, 0x1E018, PVALID},
  {0x1E01B, 0x1E021, PVALID},
  {0x1E023, 0x1E024, PVALID},
  {0x1E026, 0x1E02A, PVALID},
  {0x1E100, 0x1E12C, PVALID},
  {0x1E130, 0x1E13D, PVALID},
  {0x1E140, 0x1E149, PVALID},
  {0x1E14E, 0x1E14E, PVALID},
  {0x1E14F, 0x1E14F, DISALLOWED},
  {0x1E2C0, 0x1E2F9, PVALID},
  {0x1E2FF, 0x1E2FF, DISALLOWED},
  {0x1E800, 0x1E8C4, PVALID},
  {0x1E8C7, 0x1E8CF, DISALLOWED},
  {0x1E8D0, 0x1E8D6, PVALID},
  {0x1E900, 0x1E921, DISALLOWED},
  {0x1E922, 0x1E94B, PVALID},
  {0x1E950, 0x1E959, PVALID},
  {0x1E95E, 0x1E95F, DISALLOWED},
  {0x1EC71, 0x1ECB4, DISALLOWED},
  {0x1ED01, 0x1ED3D, DISALLOWED},
  {0x1EE00, 0x1EE03, DISALLOWED},
  {0x1EE05, 0x1EE1F, DISALLOWED},
  {0x1EE21, 0x1EE22, DISALLOWED},
  {0x1EE24, 0x1EE24, DISALLOWED},
  {0x1EE27, 0x1EE27, DISALLOWED},
  {0x1EE29, 0x1EE32, DISALLOWED},
  {0x1EE34, 0x1EE37, DISALLOWED},
  {0x1EE39, 0x1EE39, DISALLOWED},
  {0x1EE3B, 0x1EE3B, DISALLOWED},
  {0x1EE42, 0x1EE42, DISALLOWED},
  {0x1EE47, 0x1EE47, DISALLOWED},
  {0x1EE49, 0x1EE49, DISALLOWED},
  {0x1EE4B, 0x1EE4B, DISALLOWED},
  {0x1EE4D, 0x1EE4F, DISALLOWED},
  {0x1EE51, 0x1EE52, DISALLOWED},
  {0x1EE54, 0x1EE54, DISALLOWED},
  {0x1EE57, 0x1EE57, DISALLOWED},
  {0x1EE59, 0x1EE59, DISALLOWED},
  {0x1EE5B, 0x1EE5B, DISALLOWED},
  {0x1EE5D, 0x1EE5D, DISALLOWED},
  {0x1EE5F, 0x1EE5F, DISALLOWED},
  {0x1EE61, 0x1EE62, DISALLOWED},
  {0x1EE64, 0x1EE64, DISALLOWED},
  {0x1EE67, 0x1EE6A, DISALLOWED},
  {0x1EE6C, 0x1EE72, DISALLOWED},
  {0x1EE74, 0x1EE77, DISALLOWED},
  {0x1EE79, 0x1EE7C, DISALLOWED},
  {0x1EE7E, 0x1EE7E, DISALLOWED},
  {0x1EE80, 0x1EE89, DISALLOWED},
  {0x1EE8B, 0x1EE9B, DISALLOWED},
  {0x1EEA1, 0x1EEA3, DISALLOWED},
  {0x1EEA5, 0x1EEA9, DISALLOWED},
  {0x1EEAB, 0x1EEBB, DISALLOWED},
  {0x1EEF0, 0x1EEF1, DISALLOWED},
  {0x1F000, 0x1F02B, DISALLOWED},
  {0x1F030, 0x1F093, DISALLOWED},
  {0x1F0A0, 0x1F0AE, DISALLOWED},
  {0x1F0B1, 0x1F0BF, DISALLOWED},
  {0x1F0C1, 0x1F0CF, DISALLOWED},
  {0x1F0D1, 0x1F0F5, DISALLOWED},
  {0x1F100, 0x1F10C, DISALLOWED},
  {0x1F110, 0x1F16C, DISALLOWED},
  {0x1F170, 0x1F1AC, DISALLOWED},
  {0x1F1E6, 0x1F202, DISALLOWED},
  {0x1F210, 0x1F23B, DISALLOWED},
  {0x1F240, 0x1F248, DISALLOWED},
  {0x1F250, 0x1F251, DISALLOWED},
  {0x1F260, 0x1F265, DISALLOWED},
  {0x1F300, 0x1F6D5, DISALLOWED},
  {0x1F6E0, 0x1F6EC, DISALLOWED},
  {0x1F6F0, 0x1F6FA, DISALLOWED},
  {0x1F700, 0x1F773, DISALLOWED},
  {0x1F780, 0x1F7D8, DISALLOWED},
  {0x1F7E0, 0x1F7EB, DISALLOWED},
  {0x1F800, 0x1F80B, DISALLOWED},
  {0x1F810, 0x1F847, DISALLOWED},
  {0x1F850, 0x1F859, DISALLOWED},
  {0x1F860, 0x1F887, DISALLOWED},
  {0x1F890, 0x1F8AD, DISALLOWED},
  {0x1F900, 0x1F90B, DISALLOWED},
  {0x1F90D, 0x1F971, DISALLOWED},
  {0x1F973, 0x1F976, DISALLOWED},
  {0x1F97A, 0x1F9A2, DISALLOWED},
  {0x1F9A5, 0x1F9AA, DISALLOWED},
  {0x1F9AE, 0x1F9CA, DISALLOWED},
  {0x1F9CD, 0x1FA53, DISALLOWED},
  {0x1FA60, 0x1FA6D, DISALLOWED},
  {0x1FA70, 0x1FA73, DISALLOWED},
  {0x1FA78, 0x1FA7A, DISALLOWED},
  {0x1FA80, 0x1FA82, DISALLOWED},
  {0x1FA90, 0x1FA95, DISALLOWED},
  {0x1FFFE, 0x1FFFF, DISALLOWED},
  {0x20000, 0x2A6D6, PVALID},
  {0x2A700, 0x2B734, PVALID},
  {0x2B740, 0x2B81D, PVALID},
  {0x2B820, 0x2CEA1, PVALID},
  {0x2CEB0, 0x2EBE0, PVALID},
  {0x2F800, 0x2FA1D, DISALLOWED},
  {0x2FFFE, 0x2FFFF, DISALLOWED},
  {0x3FFFE, 0x3FFFF, DISALLOWED},
  {0x4FFFE, 0x4FFFF, DISALLOWED},
  {0x5FFFE, 0x5FFFF, DISALLOWED},
  {0x6FFFE, 0x6FFFF, DISALLOWED},
  {0x7FFFE, 0x7FFFF, DISALLOWED},
  {0x8FFFE, 0x8FFFF, DISALLOWED},
  {0x9FFFE, 0x9FFFF, DISALLOWED},
  {0xAFFFE, 0xAFFFF, DISALLOWED},
  {0xBFFFE, 0xBFFFF, DISALLOWED},
  {0xCFFFE, 0xCFFFF, DISALLOWED},
  {0xDFFFE, 0xDFFFF, DISALLOWED},
  {0xE0001, 0xE0001, DISALLOWED},
  {0xE0020, 0xE007F, DISALLOWED},
  {0xE0100, 0xE01EF, DISALLOWED},
  {0xEFFFE, 0x10FFFF, DISALLOWED},
};
const size_t idna_table_size = 2193;
